/*===- TableGen'erated file -------------------------------------*- C++ -*-===*\
|*                                                                            *|
|* Target Register Enum Values                                                *|
|*                                                                            *|
|* Automatically generated file, do not edit!                                 *|
|*                                                                            *|
\*===----------------------------------------------------------------------===*/

namespace llvm {

class MCRegisterClass;
extern const MCRegisterClass AArch64MCRegisterClasses[];

namespace AArch64 {
enum : unsigned {
  NoRegister,
  FFR = 1,
  FP = 2,
  FPCR = 3,
  FPMR = 4,
  FPSR = 5,
  LR = 6,
  NZCV = 7,
  SP = 8,
  VG = 9,
  WSP = 10,
  WSP_HI = 11,
  WZR = 12,
  WZR_HI = 13,
  XZR = 14,
  ZA = 15,
  B0 = 16,
  B1 = 17,
  B2 = 18,
  B3 = 19,
  B4 = 20,
  B5 = 21,
  B6 = 22,
  B7 = 23,
  B8 = 24,
  B9 = 25,
  B10 = 26,
  B11 = 27,
  B12 = 28,
  B13 = 29,
  B14 = 30,
  B15 = 31,
  B16 = 32,
  B17 = 33,
  B18 = 34,
  B19 = 35,
  B20 = 36,
  B21 = 37,
  B22 = 38,
  B23 = 39,
  B24 = 40,
  B25 = 41,
  B26 = 42,
  B27 = 43,
  B28 = 44,
  B29 = 45,
  B30 = 46,
  B31 = 47,
  D0 = 48,
  D1 = 49,
  D2 = 50,
  D3 = 51,
  D4 = 52,
  D5 = 53,
  D6 = 54,
  D7 = 55,
  D8 = 56,
  D9 = 57,
  D10 = 58,
  D11 = 59,
  D12 = 60,
  D13 = 61,
  D14 = 62,
  D15 = 63,
  D16 = 64,
  D17 = 65,
  D18 = 66,
  D19 = 67,
  D20 = 68,
  D21 = 69,
  D22 = 70,
  D23 = 71,
  D24 = 72,
  D25 = 73,
  D26 = 74,
  D27 = 75,
  D28 = 76,
  D29 = 77,
  D30 = 78,
  D31 = 79,
  H0 = 80,
  H1 = 81,
  H2 = 82,
  H3 = 83,
  H4 = 84,
  H5 = 85,
  H6 = 86,
  H7 = 87,
  H8 = 88,
  H9 = 89,
  H10 = 90,
  H11 = 91,
  H12 = 92,
  H13 = 93,
  H14 = 94,
  H15 = 95,
  H16 = 96,
  H17 = 97,
  H18 = 98,
  H19 = 99,
  H20 = 100,
  H21 = 101,
  H22 = 102,
  H23 = 103,
  H24 = 104,
  H25 = 105,
  H26 = 106,
  H27 = 107,
  H28 = 108,
  H29 = 109,
  H30 = 110,
  H31 = 111,
  P0 = 112,
  P1 = 113,
  P2 = 114,
  P3 = 115,
  P4 = 116,
  P5 = 117,
  P6 = 118,
  P7 = 119,
  P8 = 120,
  P9 = 121,
  P10 = 122,
  P11 = 123,
  P12 = 124,
  P13 = 125,
  P14 = 126,
  P15 = 127,
  PN0 = 128,
  PN1 = 129,
  PN2 = 130,
  PN3 = 131,
  PN4 = 132,
  PN5 = 133,
  PN6 = 134,
  PN7 = 135,
  PN8 = 136,
  PN9 = 137,
  PN10 = 138,
  PN11 = 139,
  PN12 = 140,
  PN13 = 141,
  PN14 = 142,
  PN15 = 143,
  Q0 = 144,
  Q1 = 145,
  Q2 = 146,
  Q3 = 147,
  Q4 = 148,
  Q5 = 149,
  Q6 = 150,
  Q7 = 151,
  Q8 = 152,
  Q9 = 153,
  Q10 = 154,
  Q11 = 155,
  Q12 = 156,
  Q13 = 157,
  Q14 = 158,
  Q15 = 159,
  Q16 = 160,
  Q17 = 161,
  Q18 = 162,
  Q19 = 163,
  Q20 = 164,
  Q21 = 165,
  Q22 = 166,
  Q23 = 167,
  Q24 = 168,
  Q25 = 169,
  Q26 = 170,
  Q27 = 171,
  Q28 = 172,
  Q29 = 173,
  Q30 = 174,
  Q31 = 175,
  S0 = 176,
  S1 = 177,
  S2 = 178,
  S3 = 179,
  S4 = 180,
  S5 = 181,
  S6 = 182,
  S7 = 183,
  S8 = 184,
  S9 = 185,
  S10 = 186,
  S11 = 187,
  S12 = 188,
  S13 = 189,
  S14 = 190,
  S15 = 191,
  S16 = 192,
  S17 = 193,
  S18 = 194,
  S19 = 195,
  S20 = 196,
  S21 = 197,
  S22 = 198,
  S23 = 199,
  S24 = 200,
  S25 = 201,
  S26 = 202,
  S27 = 203,
  S28 = 204,
  S29 = 205,
  S30 = 206,
  S31 = 207,
  W0 = 208,
  W1 = 209,
  W2 = 210,
  W3 = 211,
  W4 = 212,
  W5 = 213,
  W6 = 214,
  W7 = 215,
  W8 = 216,
  W9 = 217,
  W10 = 218,
  W11 = 219,
  W12 = 220,
  W13 = 221,
  W14 = 222,
  W15 = 223,
  W16 = 224,
  W17 = 225,
  W18 = 226,
  W19 = 227,
  W20 = 228,
  W21 = 229,
  W22 = 230,
  W23 = 231,
  W24 = 232,
  W25 = 233,
  W26 = 234,
  W27 = 235,
  W28 = 236,
  W29 = 237,
  W30 = 238,
  X0 = 239,
  X1 = 240,
  X2 = 241,
  X3 = 242,
  X4 = 243,
  X5 = 244,
  X6 = 245,
  X7 = 246,
  X8 = 247,
  X9 = 248,
  X10 = 249,
  X11 = 250,
  X12 = 251,
  X13 = 252,
  X14 = 253,
  X15 = 254,
  X16 = 255,
  X17 = 256,
  X18 = 257,
  X19 = 258,
  X20 = 259,
  X21 = 260,
  X22 = 261,
  X23 = 262,
  X24 = 263,
  X25 = 264,
  X26 = 265,
  X27 = 266,
  X28 = 267,
  Z0 = 268,
  Z1 = 269,
  Z2 = 270,
  Z3 = 271,
  Z4 = 272,
  Z5 = 273,
  Z6 = 274,
  Z7 = 275,
  Z8 = 276,
  Z9 = 277,
  Z10 = 278,
  Z11 = 279,
  Z12 = 280,
  Z13 = 281,
  Z14 = 282,
  Z15 = 283,
  Z16 = 284,
  Z17 = 285,
  Z18 = 286,
  Z19 = 287,
  Z20 = 288,
  Z21 = 289,
  Z22 = 290,
  Z23 = 291,
  Z24 = 292,
  Z25 = 293,
  Z26 = 294,
  Z27 = 295,
  Z28 = 296,
  Z29 = 297,
  Z30 = 298,
  Z31 = 299,
  ZAB0 = 300,
  ZAD0 = 301,
  ZAD1 = 302,
  ZAD2 = 303,
  ZAD3 = 304,
  ZAD4 = 305,
  ZAD5 = 306,
  ZAD6 = 307,
  ZAD7 = 308,
  ZAH0 = 309,
  ZAH1 = 310,
  ZAQ0 = 311,
  ZAQ1 = 312,
  ZAQ2 = 313,
  ZAQ3 = 314,
  ZAQ4 = 315,
  ZAQ5 = 316,
  ZAQ6 = 317,
  ZAQ7 = 318,
  ZAQ8 = 319,
  ZAQ9 = 320,
  ZAQ10 = 321,
  ZAQ11 = 322,
  ZAQ12 = 323,
  ZAQ13 = 324,
  ZAQ14 = 325,
  ZAQ15 = 326,
  ZAS0 = 327,
  ZAS1 = 328,
  ZAS2 = 329,
  ZAS3 = 330,
  ZT0 = 331,
  B0_HI = 332,
  B1_HI = 333,
  B2_HI = 334,
  B3_HI = 335,
  B4_HI = 336,
  B5_HI = 337,
  B6_HI = 338,
  B7_HI = 339,
  B8_HI = 340,
  B9_HI = 341,
  B10_HI = 342,
  B11_HI = 343,
  B12_HI = 344,
  B13_HI = 345,
  B14_HI = 346,
  B15_HI = 347,
  B16_HI = 348,
  B17_HI = 349,
  B18_HI = 350,
  B19_HI = 351,
  B20_HI = 352,
  B21_HI = 353,
  B22_HI = 354,
  B23_HI = 355,
  B24_HI = 356,
  B25_HI = 357,
  B26_HI = 358,
  B27_HI = 359,
  B28_HI = 360,
  B29_HI = 361,
  B30_HI = 362,
  B31_HI = 363,
  D0_HI = 364,
  D1_HI = 365,
  D2_HI = 366,
  D3_HI = 367,
  D4_HI = 368,
  D5_HI = 369,
  D6_HI = 370,
  D7_HI = 371,
  D8_HI = 372,
  D9_HI = 373,
  D10_HI = 374,
  D11_HI = 375,
  D12_HI = 376,
  D13_HI = 377,
  D14_HI = 378,
  D15_HI = 379,
  D16_HI = 380,
  D17_HI = 381,
  D18_HI = 382,
  D19_HI = 383,
  D20_HI = 384,
  D21_HI = 385,
  D22_HI = 386,
  D23_HI = 387,
  D24_HI = 388,
  D25_HI = 389,
  D26_HI = 390,
  D27_HI = 391,
  D28_HI = 392,
  D29_HI = 393,
  D30_HI = 394,
  D31_HI = 395,
  H0_HI = 396,
  H1_HI = 397,
  H2_HI = 398,
  H3_HI = 399,
  H4_HI = 400,
  H5_HI = 401,
  H6_HI = 402,
  H7_HI = 403,
  H8_HI = 404,
  H9_HI = 405,
  H10_HI = 406,
  H11_HI = 407,
  H12_HI = 408,
  H13_HI = 409,
  H14_HI = 410,
  H15_HI = 411,
  H16_HI = 412,
  H17_HI = 413,
  H18_HI = 414,
  H19_HI = 415,
  H20_HI = 416,
  H21_HI = 417,
  H22_HI = 418,
  H23_HI = 419,
  H24_HI = 420,
  H25_HI = 421,
  H26_HI = 422,
  H27_HI = 423,
  H28_HI = 424,
  H29_HI = 425,
  H30_HI = 426,
  H31_HI = 427,
  Q0_HI = 428,
  Q1_HI = 429,
  Q2_HI = 430,
  Q3_HI = 431,
  Q4_HI = 432,
  Q5_HI = 433,
  Q6_HI = 434,
  Q7_HI = 435,
  Q8_HI = 436,
  Q9_HI = 437,
  Q10_HI = 438,
  Q11_HI = 439,
  Q12_HI = 440,
  Q13_HI = 441,
  Q14_HI = 442,
  Q15_HI = 443,
  Q16_HI = 444,
  Q17_HI = 445,
  Q18_HI = 446,
  Q19_HI = 447,
  Q20_HI = 448,
  Q21_HI = 449,
  Q22_HI = 450,
  Q23_HI = 451,
  Q24_HI = 452,
  Q25_HI = 453,
  Q26_HI = 454,
  Q27_HI = 455,
  Q28_HI = 456,
  Q29_HI = 457,
  Q30_HI = 458,
  Q31_HI = 459,
  S0_HI = 460,
  S1_HI = 461,
  S2_HI = 462,
  S3_HI = 463,
  S4_HI = 464,
  S5_HI = 465,
  S6_HI = 466,
  S7_HI = 467,
  S8_HI = 468,
  S9_HI = 469,
  S10_HI = 470,
  S11_HI = 471,
  S12_HI = 472,
  S13_HI = 473,
  S14_HI = 474,
  S15_HI = 475,
  S16_HI = 476,
  S17_HI = 477,
  S18_HI = 478,
  S19_HI = 479,
  S20_HI = 480,
  S21_HI = 481,
  S22_HI = 482,
  S23_HI = 483,
  S24_HI = 484,
  S25_HI = 485,
  S26_HI = 486,
  S27_HI = 487,
  S28_HI = 488,
  S29_HI = 489,
  S30_HI = 490,
  S31_HI = 491,
  W0_HI = 492,
  W1_HI = 493,
  W2_HI = 494,
  W3_HI = 495,
  W4_HI = 496,
  W5_HI = 497,
  W6_HI = 498,
  W7_HI = 499,
  W8_HI = 500,
  W9_HI = 501,
  W10_HI = 502,
  W11_HI = 503,
  W12_HI = 504,
  W13_HI = 505,
  W14_HI = 506,
  W15_HI = 507,
  W16_HI = 508,
  W17_HI = 509,
  W18_HI = 510,
  W19_HI = 511,
  W20_HI = 512,
  W21_HI = 513,
  W22_HI = 514,
  W23_HI = 515,
  W24_HI = 516,
  W25_HI = 517,
  W26_HI = 518,
  W27_HI = 519,
  W28_HI = 520,
  W29_HI = 521,
  W30_HI = 522,
  D0_D1 = 523,
  D1_D2 = 524,
  D2_D3 = 525,
  D3_D4 = 526,
  D4_D5 = 527,
  D5_D6 = 528,
  D6_D7 = 529,
  D7_D8 = 530,
  D8_D9 = 531,
  D9_D10 = 532,
  D10_D11 = 533,
  D11_D12 = 534,
  D12_D13 = 535,
  D13_D14 = 536,
  D14_D15 = 537,
  D15_D16 = 538,
  D16_D17 = 539,
  D17_D18 = 540,
  D18_D19 = 541,
  D19_D20 = 542,
  D20_D21 = 543,
  D21_D22 = 544,
  D22_D23 = 545,
  D23_D24 = 546,
  D24_D25 = 547,
  D25_D26 = 548,
  D26_D27 = 549,
  D27_D28 = 550,
  D28_D29 = 551,
  D29_D30 = 552,
  D30_D31 = 553,
  D31_D0 = 554,
  D0_D1_D2_D3 = 555,
  D1_D2_D3_D4 = 556,
  D2_D3_D4_D5 = 557,
  D3_D4_D5_D6 = 558,
  D4_D5_D6_D7 = 559,
  D5_D6_D7_D8 = 560,
  D6_D7_D8_D9 = 561,
  D7_D8_D9_D10 = 562,
  D8_D9_D10_D11 = 563,
  D9_D10_D11_D12 = 564,
  D10_D11_D12_D13 = 565,
  D11_D12_D13_D14 = 566,
  D12_D13_D14_D15 = 567,
  D13_D14_D15_D16 = 568,
  D14_D15_D16_D17 = 569,
  D15_D16_D17_D18 = 570,
  D16_D17_D18_D19 = 571,
  D17_D18_D19_D20 = 572,
  D18_D19_D20_D21 = 573,
  D19_D20_D21_D22 = 574,
  D20_D21_D22_D23 = 575,
  D21_D22_D23_D24 = 576,
  D22_D23_D24_D25 = 577,
  D23_D24_D25_D26 = 578,
  D24_D25_D26_D27 = 579,
  D25_D26_D27_D28 = 580,
  D26_D27_D28_D29 = 581,
  D27_D28_D29_D30 = 582,
  D28_D29_D30_D31 = 583,
  D29_D30_D31_D0 = 584,
  D30_D31_D0_D1 = 585,
  D31_D0_D1_D2 = 586,
  D0_D1_D2 = 587,
  D1_D2_D3 = 588,
  D2_D3_D4 = 589,
  D3_D4_D5 = 590,
  D4_D5_D6 = 591,
  D5_D6_D7 = 592,
  D6_D7_D8 = 593,
  D7_D8_D9 = 594,
  D8_D9_D10 = 595,
  D9_D10_D11 = 596,
  D10_D11_D12 = 597,
  D11_D12_D13 = 598,
  D12_D13_D14 = 599,
  D13_D14_D15 = 600,
  D14_D15_D16 = 601,
  D15_D16_D17 = 602,
  D16_D17_D18 = 603,
  D17_D18_D19 = 604,
  D18_D19_D20 = 605,
  D19_D20_D21 = 606,
  D20_D21_D22 = 607,
  D21_D22_D23 = 608,
  D22_D23_D24 = 609,
  D23_D24_D25 = 610,
  D24_D25_D26 = 611,
  D25_D26_D27 = 612,
  D26_D27_D28 = 613,
  D27_D28_D29 = 614,
  D28_D29_D30 = 615,
  D29_D30_D31 = 616,
  D30_D31_D0 = 617,
  D31_D0_D1 = 618,
  P0_P1 = 619,
  P1_P2 = 620,
  P2_P3 = 621,
  P3_P4 = 622,
  P4_P5 = 623,
  P5_P6 = 624,
  P6_P7 = 625,
  P7_P8 = 626,
  P8_P9 = 627,
  P9_P10 = 628,
  P10_P11 = 629,
  P11_P12 = 630,
  P12_P13 = 631,
  P13_P14 = 632,
  P14_P15 = 633,
  P15_P0 = 634,
  Q0_Q1 = 635,
  Q1_Q2 = 636,
  Q2_Q3 = 637,
  Q3_Q4 = 638,
  Q4_Q5 = 639,
  Q5_Q6 = 640,
  Q6_Q7 = 641,
  Q7_Q8 = 642,
  Q8_Q9 = 643,
  Q9_Q10 = 644,
  Q10_Q11 = 645,
  Q11_Q12 = 646,
  Q12_Q13 = 647,
  Q13_Q14 = 648,
  Q14_Q15 = 649,
  Q15_Q16 = 650,
  Q16_Q17 = 651,
  Q17_Q18 = 652,
  Q18_Q19 = 653,
  Q19_Q20 = 654,
  Q20_Q21 = 655,
  Q21_Q22 = 656,
  Q22_Q23 = 657,
  Q23_Q24 = 658,
  Q24_Q25 = 659,
  Q25_Q26 = 660,
  Q26_Q27 = 661,
  Q27_Q28 = 662,
  Q28_Q29 = 663,
  Q29_Q30 = 664,
  Q30_Q31 = 665,
  Q31_Q0 = 666,
  Q0_Q1_Q2_Q3 = 667,
  Q1_Q2_Q3_Q4 = 668,
  Q2_Q3_Q4_Q5 = 669,
  Q3_Q4_Q5_Q6 = 670,
  Q4_Q5_Q6_Q7 = 671,
  Q5_Q6_Q7_Q8 = 672,
  Q6_Q7_Q8_Q9 = 673,
  Q7_Q8_Q9_Q10 = 674,
  Q8_Q9_Q10_Q11 = 675,
  Q9_Q10_Q11_Q12 = 676,
  Q10_Q11_Q12_Q13 = 677,
  Q11_Q12_Q13_Q14 = 678,
  Q12_Q13_Q14_Q15 = 679,
  Q13_Q14_Q15_Q16 = 680,
  Q14_Q15_Q16_Q17 = 681,
  Q15_Q16_Q17_Q18 = 682,
  Q16_Q17_Q18_Q19 = 683,
  Q17_Q18_Q19_Q20 = 684,
  Q18_Q19_Q20_Q21 = 685,
  Q19_Q20_Q21_Q22 = 686,
  Q20_Q21_Q22_Q23 = 687,
  Q21_Q22_Q23_Q24 = 688,
  Q22_Q23_Q24_Q25 = 689,
  Q23_Q24_Q25_Q26 = 690,
  Q24_Q25_Q26_Q27 = 691,
  Q25_Q26_Q27_Q28 = 692,
  Q26_Q27_Q28_Q29 = 693,
  Q27_Q28_Q29_Q30 = 694,
  Q28_Q29_Q30_Q31 = 695,
  Q29_Q30_Q31_Q0 = 696,
  Q30_Q31_Q0_Q1 = 697,
  Q31_Q0_Q1_Q2 = 698,
  Q0_Q1_Q2 = 699,
  Q1_Q2_Q3 = 700,
  Q2_Q3_Q4 = 701,
  Q3_Q4_Q5 = 702,
  Q4_Q5_Q6 = 703,
  Q5_Q6_Q7 = 704,
  Q6_Q7_Q8 = 705,
  Q7_Q8_Q9 = 706,
  Q8_Q9_Q10 = 707,
  Q9_Q10_Q11 = 708,
  Q10_Q11_Q12 = 709,
  Q11_Q12_Q13 = 710,
  Q12_Q13_Q14 = 711,
  Q13_Q14_Q15 = 712,
  Q14_Q15_Q16 = 713,
  Q15_Q16_Q17 = 714,
  Q16_Q17_Q18 = 715,
  Q17_Q18_Q19 = 716,
  Q18_Q19_Q20 = 717,
  Q19_Q20_Q21 = 718,
  Q20_Q21_Q22 = 719,
  Q21_Q22_Q23 = 720,
  Q22_Q23_Q24 = 721,
  Q23_Q24_Q25 = 722,
  Q24_Q25_Q26 = 723,
  Q25_Q26_Q27 = 724,
  Q26_Q27_Q28 = 725,
  Q27_Q28_Q29 = 726,
  Q28_Q29_Q30 = 727,
  Q29_Q30_Q31 = 728,
  Q30_Q31_Q0 = 729,
  Q31_Q0_Q1 = 730,
  X22_X23_X24_X25_X26_X27_X28_FP = 731,
  X0_X1_X2_X3_X4_X5_X6_X7 = 732,
  X2_X3_X4_X5_X6_X7_X8_X9 = 733,
  X4_X5_X6_X7_X8_X9_X10_X11 = 734,
  X6_X7_X8_X9_X10_X11_X12_X13 = 735,
  X8_X9_X10_X11_X12_X13_X14_X15 = 736,
  X10_X11_X12_X13_X14_X15_X16_X17 = 737,
  X12_X13_X14_X15_X16_X17_X18_X19 = 738,
  X14_X15_X16_X17_X18_X19_X20_X21 = 739,
  X16_X17_X18_X19_X20_X21_X22_X23 = 740,
  X18_X19_X20_X21_X22_X23_X24_X25 = 741,
  X20_X21_X22_X23_X24_X25_X26_X27 = 742,
  W30_WZR = 743,
  W0_W1 = 744,
  W2_W3 = 745,
  W4_W5 = 746,
  W6_W7 = 747,
  W8_W9 = 748,
  W10_W11 = 749,
  W12_W13 = 750,
  W14_W15 = 751,
  W16_W17 = 752,
  W18_W19 = 753,
  W20_W21 = 754,
  W22_W23 = 755,
  W24_W25 = 756,
  W26_W27 = 757,
  W28_W29 = 758,
  LR_XZR = 759,
  X28_FP = 760,
  X0_X1 = 761,
  X2_X3 = 762,
  X4_X5 = 763,
  X6_X7 = 764,
  X8_X9 = 765,
  X10_X11 = 766,
  X12_X13 = 767,
  X14_X15 = 768,
  X16_X17 = 769,
  X18_X19 = 770,
  X20_X21 = 771,
  X22_X23 = 772,
  X24_X25 = 773,
  X26_X27 = 774,
  Z0_Z1 = 775,
  Z1_Z2 = 776,
  Z2_Z3 = 777,
  Z3_Z4 = 778,
  Z4_Z5 = 779,
  Z5_Z6 = 780,
  Z6_Z7 = 781,
  Z7_Z8 = 782,
  Z8_Z9 = 783,
  Z9_Z10 = 784,
  Z10_Z11 = 785,
  Z11_Z12 = 786,
  Z12_Z13 = 787,
  Z13_Z14 = 788,
  Z14_Z15 = 789,
  Z15_Z16 = 790,
  Z16_Z17 = 791,
  Z17_Z18 = 792,
  Z18_Z19 = 793,
  Z19_Z20 = 794,
  Z20_Z21 = 795,
  Z21_Z22 = 796,
  Z22_Z23 = 797,
  Z23_Z24 = 798,
  Z24_Z25 = 799,
  Z25_Z26 = 800,
  Z26_Z27 = 801,
  Z27_Z28 = 802,
  Z28_Z29 = 803,
  Z29_Z30 = 804,
  Z30_Z31 = 805,
  Z31_Z0 = 806,
  Z0_Z1_Z2_Z3 = 807,
  Z1_Z2_Z3_Z4 = 808,
  Z2_Z3_Z4_Z5 = 809,
  Z3_Z4_Z5_Z6 = 810,
  Z4_Z5_Z6_Z7 = 811,
  Z5_Z6_Z7_Z8 = 812,
  Z6_Z7_Z8_Z9 = 813,
  Z7_Z8_Z9_Z10 = 814,
  Z8_Z9_Z10_Z11 = 815,
  Z9_Z10_Z11_Z12 = 816,
  Z10_Z11_Z12_Z13 = 817,
  Z11_Z12_Z13_Z14 = 818,
  Z12_Z13_Z14_Z15 = 819,
  Z13_Z14_Z15_Z16 = 820,
  Z14_Z15_Z16_Z17 = 821,
  Z15_Z16_Z17_Z18 = 822,
  Z16_Z17_Z18_Z19 = 823,
  Z17_Z18_Z19_Z20 = 824,
  Z18_Z19_Z20_Z21 = 825,
  Z19_Z20_Z21_Z22 = 826,
  Z20_Z21_Z22_Z23 = 827,
  Z21_Z22_Z23_Z24 = 828,
  Z22_Z23_Z24_Z25 = 829,
  Z23_Z24_Z25_Z26 = 830,
  Z24_Z25_Z26_Z27 = 831,
  Z25_Z26_Z27_Z28 = 832,
  Z26_Z27_Z28_Z29 = 833,
  Z27_Z28_Z29_Z30 = 834,
  Z28_Z29_Z30_Z31 = 835,
  Z29_Z30_Z31_Z0 = 836,
  Z30_Z31_Z0_Z1 = 837,
  Z31_Z0_Z1_Z2 = 838,
  Z0_Z1_Z2 = 839,
  Z1_Z2_Z3 = 840,
  Z2_Z3_Z4 = 841,
  Z3_Z4_Z5 = 842,
  Z4_Z5_Z6 = 843,
  Z5_Z6_Z7 = 844,
  Z6_Z7_Z8 = 845,
  Z7_Z8_Z9 = 846,
  Z8_Z9_Z10 = 847,
  Z9_Z10_Z11 = 848,
  Z10_Z11_Z12 = 849,
  Z11_Z12_Z13 = 850,
  Z12_Z13_Z14 = 851,
  Z13_Z14_Z15 = 852,
  Z14_Z15_Z16 = 853,
  Z15_Z16_Z17 = 854,
  Z16_Z17_Z18 = 855,
  Z17_Z18_Z19 = 856,
  Z18_Z19_Z20 = 857,
  Z19_Z20_Z21 = 858,
  Z20_Z21_Z22 = 859,
  Z21_Z22_Z23 = 860,
  Z22_Z23_Z24 = 861,
  Z23_Z24_Z25 = 862,
  Z24_Z25_Z26 = 863,
  Z25_Z26_Z27 = 864,
  Z26_Z27_Z28 = 865,
  Z27_Z28_Z29 = 866,
  Z28_Z29_Z30 = 867,
  Z29_Z30_Z31 = 868,
  Z30_Z31_Z0 = 869,
  Z31_Z0_Z1 = 870,
  Z16_Z24 = 871,
  Z17_Z25 = 872,
  Z18_Z26 = 873,
  Z19_Z27 = 874,
  Z20_Z28 = 875,
  Z21_Z29 = 876,
  Z22_Z30 = 877,
  Z23_Z31 = 878,
  Z0_Z8 = 879,
  Z1_Z9 = 880,
  Z2_Z10 = 881,
  Z3_Z11 = 882,
  Z4_Z12 = 883,
  Z5_Z13 = 884,
  Z6_Z14 = 885,
  Z7_Z15 = 886,
  Z16_Z20_Z24_Z28 = 887,
  Z17_Z21_Z25_Z29 = 888,
  Z18_Z22_Z26_Z30 = 889,
  Z19_Z23_Z27_Z31 = 890,
  Z0_Z4_Z8_Z12 = 891,
  Z1_Z5_Z9_Z13 = 892,
  Z2_Z6_Z10_Z14 = 893,
  Z3_Z7_Z11_Z15 = 894,
  NUM_TARGET_REGS // 895
};
} // end namespace AArch64

// Register classes

namespace AArch64 {
enum {
  W_HI_DummyRCRegClassID = 0,
  B_HI_DummyRCRegClassID = 1,
  D_HI_DummyRCRegClassID = 2,
  H_HI_DummyRCRegClassID = 3,
  Q_HI_DummyRCRegClassID = 4,
  S_HI_DummyRCRegClassID = 5,
  FPR8RegClassID = 6,
  FPR16RegClassID = 7,
  PPRorPNRRegClassID = 8,
  FPR16_loRegClassID = 9,
  PNRRegClassID = 10,
  PPRRegClassID = 11,
  PNR_3bRegClassID = 12,
  PNR_p8to15RegClassID = 13,
  PPRMul2RegClassID = 14,
  PPR_3bRegClassID = 15,
  PPR_p8to15RegClassID = 16,
  PPRMul2_and_PPR_3bRegClassID = 17,
  PPRMul2_and_PPR_p8to15RegClassID = 18,
  PPR2RegClassID = 19,
  PPR2Mul2RegClassID = 20,
  PPR2_with_psub1_in_PPRMul2RegClassID = 21,
  PPR2_with_psub1_in_PPR_3bRegClassID = 22,
  PPR2_with_psub1_in_PPR_p8to15RegClassID = 23,
  PPR2_with_psub_in_PNR_3bRegClassID = 24,
  PPR2_with_psub_in_PNR_p8to15RegClassID = 25,
  PPR2_with_psub_in_PNR_3b_and_PPR2_with_psub1_in_PPR_3bRegClassID = 26,
  PPR2_with_psub_in_PNR_p8to15_and_PPR2_with_psub1_in_PPR_p8to15RegClassID = 27,
  PPR2Mul2_and_PPR2_with_psub_in_PNR_3bRegClassID = 28,
  PPR2Mul2_and_PPR2_with_psub_in_PNR_p8to15RegClassID = 29,
  PPR2_with_psub1_in_PPRMul2_and_PPR_3bRegClassID = 30,
  PPR2_with_psub1_in_PPRMul2_and_PPR_p8to15RegClassID = 31,
  PPR2_with_psub_in_PNR_3b_and_PPR2_with_psub1_in_PPRMul2RegClassID = 32,
  PPR2_with_psub_in_PNR_p8to15_and_PPR2_with_psub1_in_PPRMul2RegClassID = 33,
  PPR2_with_psub_in_PNR_3b_and_PPR2_with_psub1_in_PPRMul2_and_PPR_3bRegClassID = 34,
  PPR2_with_psub_in_PNR_p8to15_and_PPR2_with_psub1_in_PPRMul2_and_PPR_p8to15RegClassID = 35,
  PPR2_with_psub_in_PNR_3b_and_PPR2_with_psub1_in_PPR_p8to15RegClassID = 36,
  PPR2_with_psub_in_PNR_p8to15_and_PPR2_with_psub1_in_PPR_3bRegClassID = 37,
  GPR32allRegClassID = 38,
  FPR32RegClassID = 39,
  GPR32RegClassID = 40,
  GPR32spRegClassID = 41,
  GPR32commonRegClassID = 42,
  FPR32_with_hsub_in_FPR16_loRegClassID = 43,
  GPR32argRegClassID = 44,
  MatrixIndexGPR32_12_15RegClassID = 45,
  MatrixIndexGPR32_8_11RegClassID = 46,
  CCRRegClassID = 47,
  GPR32sponlyRegClassID = 48,
  WSeqPairsClassRegClassID = 49,
  WSeqPairsClass_with_subo32_in_GPR32commonRegClassID = 50,
  WSeqPairsClass_with_sube32_in_GPR32argRegClassID = 51,
  WSeqPairsClass_with_sube32_in_MatrixIndexGPR32_12_15RegClassID = 52,
  WSeqPairsClass_with_sube32_in_MatrixIndexGPR32_8_11RegClassID = 53,
  GPR64allRegClassID = 54,
  FPR64RegClassID = 55,
  GPR64RegClassID = 56,
  GPR64spRegClassID = 57,
  GPR64commonRegClassID = 58,
  GPR64noipRegClassID = 59,
  GPR64common_and_GPR64noipRegClassID = 60,
  tcGPR64RegClassID = 61,
  tcGPRnotx16RegClassID = 62,
  tcGPRnotx16x17RegClassID = 63,
  FPR64_loRegClassID = 64,
  GPR64argRegClassID = 65,
  FIXED_REGSRegClassID = 66,
  GPR64_with_sub_32_in_MatrixIndexGPR32_12_15RegClassID = 67,
  GPR64_with_sub_32_in_MatrixIndexGPR32_8_11RegClassID = 68,
  FIXED_REGS_with_sub_32RegClassID = 69,
  tcGPRx16x17RegClassID = 70,
  FIXED_REGS_and_GPR64RegClassID = 71,
  GPR64sponlyRegClassID = 72,
  tcGPRx17RegClassID = 73,
  DDRegClassID = 74,
  DD_with_dsub0_in_FPR64_loRegClassID = 75,
  DD_with_dsub1_in_FPR64_loRegClassID = 76,
  XSeqPairsClassRegClassID = 77,
  DD_with_dsub0_in_FPR64_lo_and_DD_with_dsub1_in_FPR64_loRegClassID = 78,
  XSeqPairsClass_with_subo64_in_GPR64commonRegClassID = 79,
  XSeqPairsClass_with_subo64_in_GPR64noipRegClassID = 80,
  XSeqPairsClass_with_sube64_in_GPR64noipRegClassID = 81,
  XSeqPairsClass_with_sube64_in_tcGPR64RegClassID = 82,
  XSeqPairsClass_with_sube64_in_tcGPRnotx16RegClassID = 83,
  XSeqPairsClass_with_subo64_in_tcGPR64RegClassID = 84,
  XSeqPairsClass_with_subo64_in_tcGPRnotx16x17RegClassID = 85,
  XSeqPairsClass_with_sube64_in_GPR64argRegClassID = 86,
  XSeqPairsClass_with_sube64_in_GPR64_with_sub_32_in_MatrixIndexGPR32_12_15RegClassID = 87,
  XSeqPairsClass_with_sube64_in_GPR64_with_sub_32_in_MatrixIndexGPR32_8_11RegClassID = 88,
  XSeqPairsClass_with_sube64_in_tcGPRx16x17RegClassID = 89,
  XSeqPairsClass_with_subo64_in_FIXED_REGSRegClassID = 90,
  FPR128RegClassID = 91,
  ZPRRegClassID = 92,
  FPR128_loRegClassID = 93,
  MPR128RegClassID = 94,
  ZPRMul2RegClassID = 95,
  ZPR_4bRegClassID = 96,
  FPR128_0to7RegClassID = 97,
  ZPRMul2_HiRegClassID = 98,
  ZPRMul2_LoRegClassID = 99,
  ZPRMul4RegClassID = 100,
  ZPR_3bRegClassID = 101,
  ZPR_KRegClassID = 102,
  ZPRMul2_Hi_and_ZPRMul4RegClassID = 103,
  ZPRMul2_Lo_and_ZPRMul4RegClassID = 104,
  ZPRMul2_and_ZPR_3bRegClassID = 105,
  ZPRMul2_and_ZPR_KRegClassID = 106,
  ZPRMul4_and_ZPR_3bRegClassID = 107,
  ZPRMul4_and_ZPR_KRegClassID = 108,
  DDDRegClassID = 109,
  DDD_with_dsub0_in_FPR64_loRegClassID = 110,
  DDD_with_dsub1_in_FPR64_loRegClassID = 111,
  DDD_with_dsub2_in_FPR64_loRegClassID = 112,
  DDD_with_dsub0_in_FPR64_lo_and_DDD_with_dsub1_in_FPR64_loRegClassID = 113,
  DDD_with_dsub1_in_FPR64_lo_and_DDD_with_dsub2_in_FPR64_loRegClassID = 114,
  DDD_with_dsub0_in_FPR64_lo_and_DDD_with_dsub2_in_FPR64_loRegClassID = 115,
  DDDDRegClassID = 116,
  DDDD_with_dsub0_in_FPR64_loRegClassID = 117,
  DDDD_with_dsub1_in_FPR64_loRegClassID = 118,
  DDDD_with_dsub2_in_FPR64_loRegClassID = 119,
  DDDD_with_dsub3_in_FPR64_loRegClassID = 120,
  DDDD_with_dsub0_in_FPR64_lo_and_DDDD_with_dsub1_in_FPR64_loRegClassID = 121,
  DDDD_with_dsub1_in_FPR64_lo_and_DDDD_with_dsub2_in_FPR64_loRegClassID = 122,
  DDDD_with_dsub2_in_FPR64_lo_and_DDDD_with_dsub3_in_FPR64_loRegClassID = 123,
  DDDD_with_dsub0_in_FPR64_lo_and_DDDD_with_dsub2_in_FPR64_loRegClassID = 124,
  DDDD_with_dsub1_in_FPR64_lo_and_DDDD_with_dsub3_in_FPR64_loRegClassID = 125,
  DDDD_with_dsub0_in_FPR64_lo_and_DDDD_with_dsub3_in_FPR64_loRegClassID = 126,
  QQRegClassID = 127,
  ZPR2RegClassID = 128,
  ZPR2StridedOrContiguousRegClassID = 129,
  ZPR2StridedOrContiguous_with_zsub0_in_ZPRMul2RegClassID = 130,
  QQ_with_dsub1_in_FPR64_loRegClassID = 131,
  QQ_with_qsub0_in_FPR128_loRegClassID = 132,
  ZPR2Mul2RegClassID = 133,
  ZPR2StridedRegClassID = 134,
  ZPR2StridedOrContiguous_with_dsub_in_FPR64_loRegClassID = 135,
  ZPR2_with_dsub1_in_FPR64_loRegClassID = 136,
  ZPR2_with_zsub1_in_ZPRMul2RegClassID = 137,
  ZPR2_with_zsub_in_FPR128_loRegClassID = 138,
  QQ_with_qsub0_in_FPR128_lo_and_QQ_with_dsub1_in_FPR64_loRegClassID = 139,
  ZPR2_with_zsub_in_FPR128_lo_and_ZPR2_with_dsub1_in_FPR64_loRegClassID = 140,
  ZPR2StridedOrContiguous_with_zsub0_in_ZPRMul2_HiRegClassID = 141,
  ZPR2StridedOrContiguous_with_zsub0_in_ZPRMul2_LoRegClassID = 142,
  ZPR2StridedOrContiguous_with_zsub0_in_ZPRMul4RegClassID = 143,
  ZPR2StridedOrContiguous_with_zsub_in_FPR128_0to7RegClassID = 144,
  QQ_with_qsub0_in_FPR128_0to7RegClassID = 145,
  QQ_with_qsub1_in_FPR128_0to7RegClassID = 146,
  ZPR2Mul2_HiRegClassID = 147,
  ZPR2Mul2_LoRegClassID = 148,
  ZPR2StridedOrContiguous_with_zsub0_in_ZPRMul2_and_ZPR_3bRegClassID = 149,
  ZPR2StridedOrContiguous_with_zsub0_in_ZPR_KRegClassID = 150,
  ZPR2Strided_with_dsub_in_FPR64_loRegClassID = 151,
  ZPR2Strided_with_zsub0_in_ZPRMul2RegClassID = 152,
  ZPR2_with_qsub1_in_FPR128_0to7RegClassID = 153,
  ZPR2_with_zsub0_in_ZPRMul4RegClassID = 154,
  ZPR2_with_zsub0_in_ZPR_KRegClassID = 155,
  ZPR2_with_zsub1_in_ZPRMul2_HiRegClassID = 156,
  ZPR2_with_zsub1_in_ZPRMul2_LoRegClassID = 157,
  ZPR2_with_zsub1_in_ZPRMul4RegClassID = 158,
  ZPR2_with_zsub1_in_ZPR_KRegClassID = 159,
  ZPR2_with_zsub_in_FPR128_0to7RegClassID = 160,
  ZPR2_with_zsub_in_FPR128_lo_and_ZPR2_with_zsub1_in_ZPRMul2RegClassID = 161,
  QQ_with_qsub0_in_FPR128_0to7_and_QQ_with_qsub1_in_FPR128_0to7RegClassID = 162,
  ZPR2_with_zsub_in_FPR128_0to7_and_ZPR2_with_qsub1_in_FPR128_0to7RegClassID = 163,
  ZPR2_with_zsub_in_FPR128_lo_and_ZPR2_with_zsub1_in_ZPRMul2_LoRegClassID = 164,
  ZPR2StridedOrContiguous_with_zsub0_in_ZPRMul2_Hi_and_ZPRMul4RegClassID = 165,
  ZPR2StridedOrContiguous_with_zsub0_in_ZPRMul2_Lo_and_ZPRMul4RegClassID = 166,
  ZPR2StridedOrContiguous_with_zsub0_in_ZPRMul2_and_ZPR_KRegClassID = 167,
  ZPR2_with_zsub0_in_ZPR_K_and_ZPR2_with_zsub1_in_ZPR_KRegClassID = 168,
  ZPR2Mul2_Hi_and_ZPR2_with_zsub0_in_ZPRMul4RegClassID = 169,
  ZPR2Mul2_Lo_and_ZPR2_with_zsub0_in_ZPRMul4RegClassID = 170,
  ZPR2Mul2_and_ZPR2_with_zsub0_in_ZPR_KRegClassID = 171,
  ZPR2Mul2_and_ZPR2_with_zsub_in_FPR128_0to7RegClassID = 172,
  ZPR2StridedOrContiguous_with_zsub0_in_ZPRMul4_and_ZPR_3bRegClassID = 173,
  ZPR2Strided_with_zsub0_in_ZPRMul2_HiRegClassID = 174,
  ZPR2Strided_with_zsub0_in_ZPRMul2_LoRegClassID = 175,
  ZPR2Strided_with_zsub0_in_ZPRMul4RegClassID = 176,
  ZPR2Strided_with_zsub0_in_ZPR_KRegClassID = 177,
  ZPR2_with_zsub0_in_ZPR_K_and_ZPR2_with_zsub1_in_ZPRMul2RegClassID = 178,
  ZPR2_with_zsub1_in_ZPRMul2_Hi_and_ZPRMul4RegClassID = 179,
  ZPR2_with_zsub1_in_ZPRMul2_Lo_and_ZPRMul4RegClassID = 180,
  ZPR2_with_zsub1_in_ZPRMul2_and_ZPR_3bRegClassID = 181,
  ZPR2_with_zsub1_in_ZPRMul2_and_ZPR_KRegClassID = 182,
  ZPR2_with_zsub_in_FPR128_0to7_and_ZPR2_with_zsub1_in_ZPRMul2RegClassID = 183,
  ZPR2_with_zsub_in_FPR128_lo_and_ZPR2_with_zsub1_in_ZPRMul4RegClassID = 184,
  ZPR2StridedOrContiguous_with_zsub0_in_ZPRMul4_and_ZPR_KRegClassID = 185,
  ZPR2_with_zsub0_in_ZPR_K_and_ZPR2_with_zsub1_in_ZPRMul2_HiRegClassID = 186,
  ZPR2_with_zsub_in_FPR128_0to7_and_ZPR2_with_zsub1_in_ZPRMul2_and_ZPR_3bRegClassID = 187,
  ZPR2_with_zsub_in_FPR128_lo_and_ZPR2_with_zsub1_in_ZPRMul2_Lo_and_ZPRMul4RegClassID = 188,
  ZPR2Strided_with_zsub0_in_ZPRMul2_Hi_and_ZPRMul4RegClassID = 189,
  ZPR2Strided_with_zsub0_in_ZPRMul2_Lo_and_ZPRMul4RegClassID = 190,
  ZPR2Strided_with_zsub0_in_ZPRMul2_and_ZPR_KRegClassID = 191,
  ZPR2_with_zsub0_in_ZPRMul4_and_ZPR_3bRegClassID = 192,
  ZPR2_with_zsub0_in_ZPRMul4_and_ZPR_KRegClassID = 193,
  ZPR2_with_zsub0_in_ZPR_K_and_ZPR2_with_zsub1_in_ZPRMul2_and_ZPR_KRegClassID = 194,
  ZPR2_with_zsub0_in_ZPR_K_and_ZPR2_with_zsub1_in_ZPRMul4RegClassID = 195,
  ZPR2_with_zsub1_in_ZPRMul4_and_ZPR_3bRegClassID = 196,
  ZPR2_with_zsub1_in_ZPRMul4_and_ZPR_KRegClassID = 197,
  ZPR2_with_zsub_in_FPR128_0to7_and_ZPR2_with_zsub1_in_ZPRMul4RegClassID = 198,
  ZPR2Strided_with_zsub0_in_ZPRMul4_and_ZPR_KRegClassID = 199,
  ZPR2_with_dsub1_in_FPR64_lo_and_ZPR2_with_zsub0_in_ZPR_KRegClassID = 200,
  ZPR2_with_zsub0_in_ZPR_K_and_ZPR2_with_zsub1_in_ZPRMul2_Hi_and_ZPRMul4RegClassID = 201,
  ZPR2_with_zsub_in_FPR128_0to7_and_ZPR2_with_zsub1_in_ZPRMul4_and_ZPR_3bRegClassID = 202,
  ZPR2_with_zsub_in_FPR128_lo_and_ZPR2_with_zsub1_in_ZPRMul2_HiRegClassID = 203,
  MPR64RegClassID = 204,
  QQQRegClassID = 205,
  ZPR3RegClassID = 206,
  QQQ_with_dsub1_in_FPR64_loRegClassID = 207,
  QQQ_with_dsub2_in_FPR64_loRegClassID = 208,
  QQQ_with_qsub0_in_FPR128_loRegClassID = 209,
  ZPR3_with_dsub1_in_FPR64_loRegClassID = 210,
  ZPR3_with_dsub2_in_FPR64_loRegClassID = 211,
  ZPR3_with_zsub0_zsub1_in_ZPR2Mul2RegClassID = 212,
  ZPR3_with_zsub1_in_ZPRMul2RegClassID = 213,
  ZPR3_with_zsub_in_FPR128_loRegClassID = 214,
  QQQ_with_dsub1_in_FPR64_lo_and_QQQ_with_dsub2_in_FPR64_loRegClassID = 215,
  QQQ_with_qsub0_in_FPR128_lo_and_QQQ_with_dsub1_in_FPR64_loRegClassID = 216,
  ZPR3_with_dsub1_in_FPR64_lo_and_ZPR3_with_dsub2_in_FPR64_loRegClassID = 217,
  ZPR3_with_zsub_in_FPR128_lo_and_ZPR3_with_dsub1_in_FPR64_loRegClassID = 218,
  QQQ_with_qsub0_in_FPR128_lo_and_QQQ_with_dsub2_in_FPR64_loRegClassID = 219,
  ZPR3_with_zsub_in_FPR128_lo_and_ZPR3_with_dsub2_in_FPR64_loRegClassID = 220,
  QQQ_with_qsub0_in_FPR128_0to7RegClassID = 221,
  QQQ_with_qsub1_in_FPR128_0to7RegClassID = 222,
  QQQ_with_qsub2_in_FPR128_0to7RegClassID = 223,
  ZPR3_with_qsub1_in_FPR128_0to7RegClassID = 224,
  ZPR3_with_qsub2_in_FPR128_0to7RegClassID = 225,
  ZPR3_with_zsub0_in_ZPRMul4RegClassID = 226,
  ZPR3_with_zsub0_in_ZPR_KRegClassID = 227,
  ZPR3_with_zsub0_zsub1_in_ZPR2Mul2_HiRegClassID = 228,
  ZPR3_with_zsub0_zsub1_in_ZPR2Mul2_LoRegClassID = 229,
  ZPR3_with_zsub1_in_ZPRMul2_HiRegClassID = 230,
  ZPR3_with_zsub1_in_ZPRMul2_LoRegClassID = 231,
  ZPR3_with_zsub1_in_ZPRMul4RegClassID = 232,
  ZPR3_with_zsub1_in_ZPR_KRegClassID = 233,
  ZPR3_with_zsub2_in_ZPRMul2_HiRegClassID = 234,
  ZPR3_with_zsub2_in_ZPRMul2_LoRegClassID = 235,
  ZPR3_with_zsub2_in_ZPRMul4RegClassID = 236,
  ZPR3_with_zsub2_in_ZPR_KRegClassID = 237,
  ZPR3_with_zsub_in_FPR128_0to7RegClassID = 238,
  ZPR3_with_zsub_in_FPR128_lo_and_ZPR3_with_zsub1_in_ZPRMul2RegClassID = 239,
  QQQ_with_dsub1_in_FPR64_lo_and_QQQ_with_qsub2_in_FPR128_0to7RegClassID = 240,
  QQQ_with_qsub0_in_FPR128_0to7_and_QQQ_with_qsub1_in_FPR128_0to7RegClassID = 241,
  ZPR3_with_dsub1_in_FPR64_lo_and_ZPR3_with_qsub2_in_FPR128_0to7RegClassID = 242,
  ZPR3_with_zsub0_zsub1_in_ZPR2Mul2_Hi_and_ZPR3_with_zsub2_in_ZPRMul2_HiRegClassID = 243,
  ZPR3_with_zsub_in_FPR128_0to7_and_ZPR3_with_qsub1_in_FPR128_0to7RegClassID = 244,
  ZPR3_with_zsub_in_FPR128_lo_and_ZPR3_with_zsub1_in_ZPRMul2_LoRegClassID = 245,
  ZPR3_with_zsub_in_FPR128_lo_and_ZPR3_with_zsub2_in_ZPRMul2_LoRegClassID = 246,
  QQQ_with_qsub0_in_FPR128_0to7_and_QQQ_with_qsub2_in_FPR128_0to7RegClassID = 247,
  ZPR3_with_zsub0_in_ZPR_K_and_ZPR3_with_zsub1_in_ZPR_KRegClassID = 248,
  ZPR3_with_zsub1_in_ZPR_K_and_ZPR3_with_zsub2_in_ZPR_KRegClassID = 249,
  ZPR3_with_zsub_in_FPR128_0to7_and_ZPR3_with_qsub2_in_FPR128_0to7RegClassID = 250,
  ZPR3_with_zsub0_in_ZPR_K_and_ZPR3_with_zsub1_in_ZPRMul2RegClassID = 251,
  ZPR3_with_zsub0_in_ZPR_K_and_ZPR3_with_zsub2_in_ZPR_KRegClassID = 252,
  ZPR3_with_zsub0_zsub1_in_ZPR2Mul2_Hi_and_ZPR2_with_zsub0_in_ZPRMul4RegClassID = 253,
  ZPR3_with_zsub0_zsub1_in_ZPR2Mul2_Hi_and_ZPR3_with_zsub2_in_ZPRMul4RegClassID = 254,
  ZPR3_with_zsub0_zsub1_in_ZPR2Mul2_Lo_and_ZPR2_with_zsub0_in_ZPRMul4RegClassID = 255,
  ZPR3_with_zsub0_zsub1_in_ZPR2Mul2_and_ZPR2_with_zsub0_in_ZPR_KRegClassID = 256,
  ZPR3_with_zsub0_zsub1_in_ZPR2Mul2_and_ZPR2_with_zsub_in_FPR128_0to7RegClassID = 257,
  ZPR3_with_zsub1_zsub2_in_ZPR2Mul2_Hi_and_ZPR2_with_zsub0_in_ZPRMul4RegClassID = 258,
  ZPR3_with_zsub1_zsub2_in_ZPR2Mul2_Lo_and_ZPR2_with_zsub0_in_ZPRMul4RegClassID = 259,
  ZPR3_with_zsub1_zsub2_in_ZPR2Mul2_and_ZPR2_with_zsub0_in_ZPR_KRegClassID = 260,
  ZPR3_with_zsub1_zsub2_in_ZPR2Mul2_and_ZPR2_with_zsub_in_FPR128_0to7RegClassID = 261,
  ZPR3_with_zsub2_in_ZPRMul2_Hi_and_ZPRMul4RegClassID = 262,
  ZPR3_with_zsub2_in_ZPRMul2_Lo_and_ZPRMul4RegClassID = 263,
  ZPR3_with_zsub2_in_ZPRMul2_and_ZPR_3bRegClassID = 264,
  ZPR3_with_zsub2_in_ZPRMul2_and_ZPR_KRegClassID = 265,
  ZPR3_with_zsub_in_FPR128_0to7_and_ZPR3_with_zsub1_in_ZPRMul2RegClassID = 266,
  ZPR3_with_zsub_in_FPR128_lo_and_ZPR3_with_zsub1_in_ZPRMul4RegClassID = 267,
  ZPR3_with_zsub_in_FPR128_lo_and_ZPR3_with_zsub2_in_ZPRMul4RegClassID = 268,
  ZPR3_with_zsub0_in_ZPR_K_and_ZPR3_with_zsub1_in_ZPRMul2_HiRegClassID = 269,
  ZPR3_with_zsub0_zsub1_in_ZPR2Mul2_Hi_and_ZPR3_with_zsub2_in_ZPRMul2_Hi_and_ZPRMul4RegClassID = 270,
  ZPR3_with_zsub0_zsub1_in_ZPR2Mul2_with_zsub1_zsub2_in_ZPR2_with_zsub0_in_ZPR_K_and_ZPR2_with_zsub1_in_ZPRMul2_HiRegClassID = 271,
  ZPR3_with_zsub_in_FPR128_0to7_and_ZPR3_with_zsub1_zsub2_in_ZPR2Mul2_and_ZPR2_with_zsub_in_FPR128_0to7RegClassID = 272,
  ZPR3_with_zsub_in_FPR128_0to7_and_ZPR3_with_zsub2_in_ZPRMul2_and_ZPR_3bRegClassID = 273,
  ZPR3_with_zsub_in_FPR128_lo_and_ZPR3_with_zsub1_zsub2_in_ZPR2Mul2_Lo_and_ZPR2_with_zsub0_in_ZPRMul4RegClassID = 274,
  ZPR3_with_zsub_in_FPR128_lo_and_ZPR3_with_zsub2_in_ZPRMul2_Lo_and_ZPRMul4RegClassID = 275,
  ZPR3_with_dsub2_in_FPR64_lo_and_ZPR3_with_zsub0_in_ZPR_KRegClassID = 276,
  ZPR3_with_zsub0_in_ZPRMul4_and_ZPR_3bRegClassID = 277,
  ZPR3_with_zsub0_in_ZPRMul4_and_ZPR_KRegClassID = 278,
  ZPR3_with_zsub0_in_ZPR_K_and_ZPR3_with_zsub1_in_ZPRMul4RegClassID = 279,
  ZPR3_with_zsub0_in_ZPR_K_and_ZPR3_with_zsub1_zsub2_in_ZPR2Mul2_and_ZPR2_with_zsub0_in_ZPR_KRegClassID = 280,
  ZPR3_with_zsub0_zsub1_in_ZPR2Mul2_with_zsub1_zsub2_in_ZPR2_with_zsub0_in_ZPR_K_and_ZPR2_with_zsub1_in_ZPRMul4RegClassID = 281,
  ZPR3_with_zsub1_in_ZPRMul4_and_ZPR_3bRegClassID = 282,
  ZPR3_with_zsub1_in_ZPRMul4_and_ZPR_KRegClassID = 283,
  ZPR3_with_zsub2_in_ZPRMul4_and_ZPR_3bRegClassID = 284,
  ZPR3_with_zsub2_in_ZPRMul4_and_ZPR_KRegClassID = 285,
  ZPR3_with_zsub_in_FPR128_0to7_and_ZPR3_with_zsub1_in_ZPRMul4RegClassID = 286,
  ZPR3_with_zsub_in_FPR128_0to7_and_ZPR3_with_zsub2_in_ZPRMul4RegClassID = 287,
  ZPR3_with_dsub1_in_FPR64_lo_and_ZPR3_with_zsub0_in_ZPR_KRegClassID = 288,
  ZPR3_with_dsub2_in_FPR64_lo_and_ZPR3_with_zsub0_zsub1_in_ZPR2Mul2_HiRegClassID = 289,
  ZPR3_with_zsub0_in_ZPR_K_and_ZPR3_with_zsub1_zsub2_in_ZPR2Mul2_Hi_and_ZPR2_with_zsub0_in_ZPRMul4RegClassID = 290,
  ZPR3_with_zsub0_zsub1_in_ZPR2Mul2_with_zsub1_zsub2_in_ZPR2_with_zsub0_in_ZPR_K_and_ZPR2_with_zsub1_in_ZPRMul2_Hi_and_ZPRMul4RegClassID = 291,
  ZPR3_with_zsub_in_FPR128_0to7_and_ZPR3_with_zsub1_in_ZPRMul4_and_ZPR_3bRegClassID = 292,
  ZPR3_with_zsub_in_FPR128_0to7_and_ZPR3_with_zsub2_in_ZPRMul4_and_ZPR_3bRegClassID = 293,
  ZPR3_with_zsub_in_FPR128_lo_and_ZPR3_with_zsub1_in_ZPRMul2_HiRegClassID = 294,
  ZPR3_with_zsub_in_FPR128_lo_and_ZPR3_with_zsub2_in_ZPRMul2_HiRegClassID = 295,
  QQQQRegClassID = 296,
  ZPR4RegClassID = 297,
  QQQQ_with_dsub1_in_FPR64_loRegClassID = 298,
  QQQQ_with_dsub2_in_FPR64_loRegClassID = 299,
  QQQQ_with_dsub3_in_FPR64_loRegClassID = 300,
  QQQQ_with_qsub0_in_FPR128_loRegClassID = 301,
  ZPR4StridedOrContiguousRegClassID = 302,
  ZPR4_with_dsub1_in_FPR64_loRegClassID = 303,
  ZPR4_with_dsub2_in_FPR64_loRegClassID = 304,
  ZPR4_with_dsub3_in_FPR64_loRegClassID = 305,
  ZPR4_with_zsub0_zsub1_in_ZPR2Mul2RegClassID = 306,
  ZPR4_with_zsub1_in_ZPRMul2RegClassID = 307,
  ZPR4_with_zsub_in_FPR128_loRegClassID = 308,
  QQQQ_with_dsub1_in_FPR64_lo_and_QQQQ_with_dsub2_in_FPR64_loRegClassID = 309,
  QQQQ_with_dsub2_in_FPR64_lo_and_QQQQ_with_dsub3_in_FPR64_loRegClassID = 310,
  QQQQ_with_qsub0_in_FPR128_lo_and_QQQQ_with_dsub1_in_FPR64_loRegClassID = 311,
  ZPR4_with_dsub1_in_FPR64_lo_and_ZPR4_with_dsub2_in_FPR64_loRegClassID = 312,
  ZPR4_with_dsub2_in_FPR64_lo_and_ZPR4_with_dsub3_in_FPR64_loRegClassID = 313,
  ZPR4_with_zsub_in_FPR128_lo_and_ZPR4_with_dsub1_in_FPR64_loRegClassID = 314,
  QQQQ_with_dsub1_in_FPR64_lo_and_QQQQ_with_dsub3_in_FPR64_loRegClassID = 315,
  QQQQ_with_qsub0_in_FPR128_lo_and_QQQQ_with_dsub2_in_FPR64_loRegClassID = 316,
  ZPR4_with_dsub1_in_FPR64_lo_and_ZPR4_with_dsub3_in_FPR64_loRegClassID = 317,
  ZPR4_with_zsub_in_FPR128_lo_and_ZPR4_with_dsub2_in_FPR64_loRegClassID = 318,
  QQQQ_with_qsub0_in_FPR128_lo_and_QQQQ_with_dsub3_in_FPR64_loRegClassID = 319,
  ZPR4_with_zsub_in_FPR128_lo_and_ZPR4_with_dsub3_in_FPR64_loRegClassID = 320,
  ZPR4StridedOrContiguous_with_zsub0_in_ZPRMul2RegClassID = 321,
  ZPR4StridedOrContiguous_with_zsub0_in_ZPRMul4RegClassID = 322,
  QQQQ_with_qsub0_in_FPR128_0to7RegClassID = 323,
  QQQQ_with_qsub1_in_FPR128_0to7RegClassID = 324,
  QQQQ_with_qsub2_in_FPR128_0to7RegClassID = 325,
  QQQQ_with_qsub3_in_FPR128_0to7RegClassID = 326,
  ZPR4Mul4RegClassID = 327,
  ZPR4StridedRegClassID = 328,
  ZPR4StridedOrContiguous_with_dsub_in_FPR64_loRegClassID = 329,
  ZPR4_with_qsub1_in_FPR128_0to7RegClassID = 330,
  ZPR4_with_qsub2_in_FPR128_0to7RegClassID = 331,
  ZPR4_with_qsub3_in_FPR128_0to7RegClassID = 332,
  ZPR4_with_zsub0_in_ZPR_KRegClassID = 333,
  ZPR4_with_zsub0_zsub1_in_ZPR2Mul2_HiRegClassID = 334,
  ZPR4_with_zsub0_zsub1_in_ZPR2Mul2_LoRegClassID = 335,
  ZPR4_with_zsub1_in_ZPRMul2_HiRegClassID = 336,
  ZPR4_with_zsub1_in_ZPRMul2_LoRegClassID = 337,
  ZPR4_with_zsub1_in_ZPRMul4RegClassID = 338,
  ZPR4_with_zsub1_in_ZPR_KRegClassID = 339,
  ZPR4_with_zsub2_in_ZPRMul2_HiRegClassID = 340,
  ZPR4_with_zsub2_in_ZPRMul2_LoRegClassID = 341,
  ZPR4_with_zsub2_in_ZPRMul4RegClassID = 342,
  ZPR4_with_zsub2_in_ZPR_KRegClassID = 343,
  ZPR4_with_zsub3_in_ZPRMul2_HiRegClassID = 344,
  ZPR4_with_zsub3_in_ZPRMul2_LoRegClassID = 345,
  ZPR4_with_zsub3_in_ZPRMul4RegClassID = 346,
  ZPR4_with_zsub3_in_ZPR_KRegClassID = 347,
  ZPR4_with_zsub_in_FPR128_0to7RegClassID = 348,
  ZPR4_with_zsub_in_FPR128_lo_and_ZPR4_with_zsub1_in_ZPRMul2RegClassID = 349,
  QQQQ_with_dsub1_in_FPR64_lo_and_QQQQ_with_qsub2_in_FPR128_0to7RegClassID = 350,
  QQQQ_with_dsub2_in_FPR64_lo_and_QQQQ_with_qsub3_in_FPR128_0to7RegClassID = 351,
  QQQQ_with_qsub0_in_FPR128_0to7_and_QQQQ_with_qsub1_in_FPR128_0to7RegClassID = 352,
  ZPR4_with_dsub1_in_FPR64_lo_and_ZPR4_with_qsub2_in_FPR128_0to7RegClassID = 353,
  ZPR4_with_dsub1_in_FPR64_lo_and_ZPR4_with_zsub3_in_ZPRMul2_LoRegClassID = 354,
  ZPR4_with_dsub2_in_FPR64_lo_and_ZPR4_with_qsub3_in_FPR128_0to7RegClassID = 355,
  ZPR4_with_zsub0_zsub1_in_ZPR2Mul2_with_zsub0_zsub1_zsub2_in_ZPR3_with_zsub0_zsub1_in_ZPR2Mul2_Hi_and_ZPR3_with_zsub2_in_ZPRMul2_HiRegClassID = 356,
  ZPR4_with_zsub1_in_ZPRMul2_with_zsub1_zsub2_zsub3_in_ZPR3_with_zsub0_zsub1_in_ZPR2Mul2_Hi_and_ZPR3_with_zsub2_in_ZPRMul2_HiRegClassID = 357,
  ZPR4_with_zsub_in_FPR128_0to7_and_ZPR4_with_qsub1_in_FPR128_0to7RegClassID = 358,
  ZPR4_with_zsub_in_FPR128_lo_and_ZPR4_with_zsub1_in_ZPRMul2_LoRegClassID = 359,
  ZPR4_with_zsub_in_FPR128_lo_and_ZPR4_with_zsub2_in_ZPRMul2_LoRegClassID = 360,
  QQQQ_with_dsub1_in_FPR64_lo_and_QQQQ_with_qsub3_in_FPR128_0to7RegClassID = 361,
  QQQQ_with_qsub0_in_FPR128_0to7_and_QQQQ_with_qsub2_in_FPR128_0to7RegClassID = 362,
  ZPR4StridedOrContiguous_with_zsub0_in_ZPRMul2_HiRegClassID = 363,
  ZPR4StridedOrContiguous_with_zsub0_in_ZPRMul2_LoRegClassID = 364,
  ZPR4StridedOrContiguous_with_zsub1_in_ZPR_KRegClassID = 365,
  ZPR4StridedOrContiguous_with_zsub_in_FPR128_0to7RegClassID = 366,
  ZPR4_with_dsub1_in_FPR64_lo_and_ZPR4_with_qsub3_in_FPR128_0to7RegClassID = 367,
  ZPR4_with_zsub0_in_ZPR_K_and_ZPR4_with_zsub1_in_ZPR_KRegClassID = 368,
  ZPR4_with_zsub1_in_ZPR_K_and_ZPR4_with_zsub2_in_ZPR_KRegClassID = 369,
  ZPR4_with_zsub2_in_ZPR_K_and_ZPR4_with_zsub3_in_ZPR_KRegClassID = 370,
  ZPR4_with_zsub_in_FPR128_0to7_and_ZPR4_with_qsub2_in_FPR128_0to7RegClassID = 371,
  ZPR4_with_zsub_in_FPR128_lo_and_ZPR4_with_zsub3_in_ZPRMul2_LoRegClassID = 372,
  QQQQ_with_qsub0_in_FPR128_0to7_and_QQQQ_with_qsub3_in_FPR128_0to7RegClassID = 373,
  ZPR4StridedOrContiguous_with_zsub0_in_ZPRMul2_Hi_and_ZPRMul4RegClassID = 374,
  ZPR4StridedOrContiguous_with_zsub0_in_ZPRMul2_Lo_and_ZPRMul4RegClassID = 375,
  ZPR4_with_zsub_in_FPR128_0to7_and_ZPR4_with_qsub3_in_FPR128_0to7RegClassID = 376,
  ZPR4StridedOrContiguous_with_zsub0_in_ZPRMul2_and_ZPR4StridedOrContiguous_with_zsub1_in_ZPR_KRegClassID = 377,
  ZPR4StridedOrContiguous_with_zsub0_in_ZPRMul2_and_ZPR_3bRegClassID = 378,
  ZPR4Strided_with_dsub_in_FPR64_loRegClassID = 379,
  ZPR4Strided_with_zsub0_in_ZPRMul2RegClassID = 380,
  ZPR4Strided_with_zsub1_in_ZPR_KRegClassID = 381,
  ZPR4_with_zsub0_in_ZPR_K_and_ZPR4_with_zsub1_in_ZPRMul2RegClassID = 382,
  ZPR4_with_zsub0_in_ZPR_K_and_ZPR4_with_zsub2_in_ZPR_KRegClassID = 383,
  ZPR4_with_zsub0_zsub1_in_ZPR2Mul2_Hi_and_ZPR2_with_zsub0_in_ZPRMul4RegClassID = 384,
  ZPR4_with_zsub0_zsub1_in_ZPR2Mul2_Lo_and_ZPR2_with_zsub0_in_ZPRMul4RegClassID = 385,
  ZPR4_with_zsub0_zsub1_in_ZPR2Mul2_and_ZPR2_with_zsub0_in_ZPR_KRegClassID = 386,
  ZPR4_with_zsub0_zsub1_in_ZPR2Mul2_and_ZPR2_with_zsub_in_FPR128_0to7RegClassID = 387,
  ZPR4_with_zsub0_zsub1_in_ZPR2Mul2_with_zsub0_zsub1_zsub2_in_ZPR3_with_zsub0_zsub1_in_ZPR2Mul2_Hi_and_ZPR3_with_zsub2_in_ZPRMul4RegClassID = 388,
  ZPR4_with_zsub0_zsub1_zsub2_in_ZPR3_with_zsub1_zsub2_in_ZPR2Mul2_Hi_and_ZPR2_with_zsub0_in_ZPRMul4RegClassID = 389,
  ZPR4_with_zsub0_zsub1_zsub2_in_ZPR3_with_zsub1_zsub2_in_ZPR2Mul2_Lo_and_ZPR2_with_zsub0_in_ZPRMul4RegClassID = 390,
  ZPR4_with_zsub0_zsub1_zsub2_in_ZPR3_with_zsub1_zsub2_in_ZPR2Mul2_and_ZPR2_with_zsub0_in_ZPR_KRegClassID = 391,
  ZPR4_with_zsub0_zsub1_zsub2_in_ZPR3_with_zsub1_zsub2_in_ZPR2Mul2_and_ZPR2_with_zsub_in_FPR128_0to7RegClassID = 392,
  ZPR4_with_zsub1_in_ZPRMul2_with_zsub1_zsub2_zsub3_in_ZPR3_with_zsub0_zsub1_in_ZPR2Mul2_Hi_and_ZPR3_with_zsub2_in_ZPRMul4RegClassID = 393,
  ZPR4_with_zsub1_in_ZPR_K_and_ZPR4_with_zsub3_in_ZPR_KRegClassID = 394,
  ZPR4_with_zsub1_zsub2_zsub3_in_ZPR3_with_zsub1_zsub2_in_ZPR2Mul2_Hi_and_ZPR2_with_zsub0_in_ZPRMul4RegClassID = 395,
  ZPR4_with_zsub1_zsub2_zsub3_in_ZPR3_with_zsub1_zsub2_in_ZPR2Mul2_Lo_and_ZPR2_with_zsub0_in_ZPRMul4RegClassID = 396,
  ZPR4_with_zsub1_zsub2_zsub3_in_ZPR3_with_zsub1_zsub2_in_ZPR2Mul2_and_ZPR2_with_zsub0_in_ZPR_KRegClassID = 397,
  ZPR4_with_zsub1_zsub2_zsub3_in_ZPR3_with_zsub1_zsub2_in_ZPR2Mul2_and_ZPR2_with_zsub_in_FPR128_0to7RegClassID = 398,
  ZPR4_with_zsub3_in_ZPRMul2_Hi_and_ZPRMul4RegClassID = 399,
  ZPR4_with_zsub3_in_ZPRMul2_Lo_and_ZPRMul4RegClassID = 400,
  ZPR4_with_zsub3_in_ZPRMul2_and_ZPR_3bRegClassID = 401,
  ZPR4_with_zsub3_in_ZPRMul2_and_ZPR_KRegClassID = 402,
  ZPR4_with_zsub_in_FPR128_0to7_and_ZPR4_with_zsub1_in_ZPRMul2RegClassID = 403,
  ZPR4_with_zsub_in_FPR128_lo_and_ZPR4_with_zsub1_in_ZPRMul4RegClassID = 404,
  ZPR4_with_zsub_in_FPR128_lo_and_ZPR4_with_zsub2_in_ZPRMul4RegClassID = 405,
  ZPR4_with_zsub_in_FPR128_lo_and_ZPR4_with_zsub3_in_ZPRMul4RegClassID = 406,
  ZPR4StridedOrContiguous_with_zsub0_in_ZPRMul4_and_ZPR4StridedOrContiguous_with_zsub1_in_ZPR_KRegClassID = 407,
  ZPR4StridedOrContiguous_with_zsub0_in_ZPRMul4_and_ZPR_3bRegClassID = 408,
  ZPR4_with_dsub1_in_FPR64_lo_and_ZPR4_with_zsub3_in_ZPRMul2_and_ZPR_3bRegClassID = 409,
  ZPR4_with_dsub3_in_FPR64_lo_and_ZPR4_with_zsub0_in_ZPR_KRegClassID = 410,
  ZPR4_with_zsub0_in_ZPR_K_and_ZPR4_with_zsub1_in_ZPRMul2_HiRegClassID = 411,
  ZPR4_with_zsub0_zsub1_in_ZPR2Mul2_with_zsub0_zsub1_zsub2_in_ZPR3_with_zsub0_zsub1_in_ZPR2Mul2_Hi_and_ZPR3_with_zsub2_in_ZPRMul2_Hi_and_ZPRMul4RegClassID = 412,
  ZPR4_with_zsub0_zsub1_in_ZPR2Mul2_with_zsub0_zsub1_zsub2_in_ZPR3_with_zsub0_zsub1_in_ZPR2Mul2_with_zsub1_zsub2_in_ZPR2_with_zsub0_in_ZPR_K_and_ZPR2_with_zsub1_in_ZPRMul2_HiRegClassID = 413,
  ZPR4_with_zsub1_in_ZPRMul2_with_zsub1_zsub2_zsub3_in_ZPR3_with_zsub0_zsub1_in_ZPR2Mul2_Hi_and_ZPR3_with_zsub2_in_ZPRMul2_Hi_and_ZPRMul4RegClassID = 414,
  ZPR4_with_zsub1_in_ZPRMul2_with_zsub1_zsub2_zsub3_in_ZPR3_with_zsub0_zsub1_in_ZPR2Mul2_with_zsub1_zsub2_in_ZPR2_with_zsub0_in_ZPR_K_and_ZPR2_with_zsub1_in_ZPRMul2_HiRegClassID = 415,
  ZPR4_with_zsub_in_FPR128_0to7_and_ZPR4_with_zsub0_zsub1_zsub2_in_ZPR3_with_zsub1_zsub2_in_ZPR2Mul2_and_ZPR2_with_zsub_in_FPR128_0to7RegClassID = 416,
  ZPR4_with_zsub_in_FPR128_0to7_and_ZPR4_with_zsub1_zsub2_zsub3_in_ZPR3_with_zsub1_zsub2_in_ZPR2Mul2_and_ZPR2_with_zsub_in_FPR128_0to7RegClassID = 417,
  ZPR4_with_zsub_in_FPR128_lo_and_ZPR4_with_zsub0_zsub1_zsub2_in_ZPR3_with_zsub1_zsub2_in_ZPR2Mul2_Lo_and_ZPR2_with_zsub0_in_ZPRMul4RegClassID = 418,
  ZPR4_with_zsub_in_FPR128_lo_and_ZPR4_with_zsub1_zsub2_zsub3_in_ZPR3_with_zsub1_zsub2_in_ZPR2Mul2_Lo_and_ZPR2_with_zsub0_in_ZPRMul4RegClassID = 419,
  ZPR4_with_zsub_in_FPR128_lo_and_ZPR4_with_zsub3_in_ZPRMul2_Lo_and_ZPRMul4RegClassID = 420,
  ZPR4Mul4_and_ZPR4_with_zsub0_in_ZPR_KRegClassID = 421,
  ZPR4Mul4_and_ZPR4_with_zsub_in_FPR128_0to7RegClassID = 422,
  ZPR4Strided_with_zsub0_in_ZPRMul2_HiRegClassID = 423,
  ZPR4Strided_with_zsub0_in_ZPRMul2_LoRegClassID = 424,
  ZPR4Strided_with_zsub0_in_ZPRMul4RegClassID = 425,
  ZPR4_with_dsub2_in_FPR64_lo_and_ZPR4_with_zsub0_in_ZPR_KRegClassID = 426,
  ZPR4_with_dsub3_in_FPR64_lo_and_ZPR4_with_zsub1_in_ZPR_KRegClassID = 427,
  ZPR4_with_dsub3_in_FPR64_lo_with_zsub0_zsub1_in_ZPR2_with_zsub0_in_ZPR_K_and_ZPR2_with_zsub1_in_ZPRMul2RegClassID = 428,
  ZPR4_with_zsub0_in_ZPR_K_and_ZPR4_with_zsub0_zsub1_zsub2_in_ZPR3_with_zsub1_zsub2_in_ZPR2Mul2_and_ZPR2_with_zsub0_in_ZPR_KRegClassID = 429,
  ZPR4_with_zsub0_in_ZPR_K_and_ZPR4_with_zsub1_in_ZPRMul4RegClassID = 430,
  ZPR4_with_zsub0_in_ZPR_K_and_ZPR4_with_zsub3_in_ZPRMul2_HiRegClassID = 431,
  ZPR4_with_zsub0_zsub1_in_ZPR2Mul2_with_zsub0_zsub1_zsub2_in_ZPR3_with_zsub0_zsub1_in_ZPR2Mul2_with_zsub1_zsub2_in_ZPR2_with_zsub0_in_ZPR_K_and_ZPR2_with_zsub1_in_ZPRMul4RegClassID = 432,
  ZPR4_with_zsub1_in_ZPRMul4_and_ZPR_3bRegClassID = 433,
  ZPR4_with_zsub1_in_ZPRMul4_and_ZPR_KRegClassID = 434,
  ZPR4_with_zsub2_in_ZPRMul4_and_ZPR_3bRegClassID = 435,
  ZPR4_with_zsub2_in_ZPRMul4_and_ZPR_KRegClassID = 436,
  ZPR4_with_zsub3_in_ZPRMul4_and_ZPR_3bRegClassID = 437,
  ZPR4_with_zsub3_in_ZPRMul4_and_ZPR_KRegClassID = 438,
  ZPR4_with_zsub_in_FPR128_0to7_and_ZPR4_with_zsub1_in_ZPRMul4RegClassID = 439,
  ZPR4_with_zsub_in_FPR128_0to7_and_ZPR4_with_zsub2_in_ZPRMul4RegClassID = 440,
  ZPR4_with_zsub_in_FPR128_0to7_and_ZPR4_with_zsub3_in_ZPRMul2_and_ZPR_3bRegClassID = 441,
  ZPR4_with_zsub_in_FPR128_0to7_and_ZPR4_with_zsub3_in_ZPRMul4RegClassID = 442,
  ZPR4_with_zsub_in_FPR128_lo_and_ZPR4_with_zsub3_in_ZPRMul2_HiRegClassID = 443,
  ZPR4Strided_with_zsub0_in_ZPRMul2_Hi_and_ZPRMul4RegClassID = 444,
  ZPR4Strided_with_zsub0_in_ZPRMul2_Lo_and_ZPRMul4RegClassID = 445,
  ZPR4_with_dsub1_in_FPR64_lo_and_ZPR4_with_zsub0_in_ZPR_KRegClassID = 446,
  ZPR4_with_dsub2_in_FPR64_lo_and_ZPR4_with_zsub0_zsub1_in_ZPR2Mul2_HiRegClassID = 447,
  ZPR4_with_dsub3_in_FPR64_lo_and_ZPR4_with_zsub1_in_ZPRMul2_HiRegClassID = 448,
  ZPR4_with_zsub0_in_ZPR_K_and_ZPR4_with_zsub0_zsub1_zsub2_in_ZPR3_with_zsub1_zsub2_in_ZPR2Mul2_Hi_and_ZPR2_with_zsub0_in_ZPRMul4RegClassID = 449,
  ZPR4_with_zsub0_in_ZPR_K_and_ZPR4_with_zsub3_in_ZPRMul2_Hi_and_ZPRMul4RegClassID = 450,
  ZPR4_with_zsub0_zsub1_in_ZPR2Mul2_with_zsub0_zsub1_zsub2_in_ZPR3_with_zsub0_zsub1_in_ZPR2Mul2_with_zsub1_zsub2_in_ZPR2_with_zsub0_in_ZPR_K_and_ZPR2_with_zsub1_in_ZPRMul2_Hi_and_ZPRMul4RegClassID = 451,
  ZPR4_with_zsub_in_FPR128_0to7_and_ZPR4_with_zsub1_in_ZPRMul4_and_ZPR_3bRegClassID = 452,
  ZPR4_with_zsub_in_FPR128_0to7_and_ZPR4_with_zsub2_in_ZPRMul4_and_ZPR_3bRegClassID = 453,
  ZPR4_with_zsub_in_FPR128_0to7_and_ZPR4_with_zsub3_in_ZPRMul4_and_ZPR_3bRegClassID = 454,
  ZPR4_with_zsub_in_FPR128_lo_and_ZPR4_with_zsub1_in_ZPRMul2_HiRegClassID = 455,
  ZPR4_with_zsub_in_FPR128_lo_and_ZPR4_with_zsub2_in_ZPRMul2_HiRegClassID = 456,
  ZPR4_with_zsub_in_FPR128_lo_and_ZPR4_with_zsub3_in_ZPRMul2_Hi_and_ZPRMul4RegClassID = 457,
  GPR64x8ClassRegClassID = 458,
  GPR64x8Class_with_x8sub_0_in_GPR64noipRegClassID = 459,
  GPR64x8Class_with_x8sub_2_in_GPR64noipRegClassID = 460,
  GPR64x8Class_with_x8sub_4_in_GPR64noipRegClassID = 461,
  GPR64x8Class_with_x8sub_6_in_GPR64noipRegClassID = 462,
  GPR64x8Class_with_x8sub_0_in_GPR64noip_and_GPR64x8Class_with_x8sub_2_in_GPR64noipRegClassID = 463,
  GPR64x8Class_with_x8sub_0_in_GPR64noip_and_GPR64x8Class_with_x8sub_4_in_GPR64noipRegClassID = 464,
  GPR64x8Class_with_x8sub_0_in_GPR64noip_and_GPR64x8Class_with_x8sub_6_in_GPR64noipRegClassID = 465,
  GPR64x8Class_with_x8sub_0_in_tcGPR64RegClassID = 466,
  GPR64x8Class_with_x8sub_2_in_GPR64noip_and_GPR64x8Class_with_x8sub_4_in_GPR64noipRegClassID = 467,
  GPR64x8Class_with_x8sub_2_in_GPR64noip_and_GPR64x8Class_with_x8sub_6_in_GPR64noipRegClassID = 468,
  GPR64x8Class_with_x8sub_4_in_GPR64noip_and_GPR64x8Class_with_x8sub_6_in_GPR64noipRegClassID = 469,
  GPR64x8Class_with_x8sub_0_in_tcGPR64_and_GPR64x8Class_with_x8sub_2_in_GPR64noipRegClassID = 470,
  GPR64x8Class_with_x8sub_0_in_tcGPR64_and_GPR64x8Class_with_x8sub_4_in_GPR64noipRegClassID = 471,
  GPR64x8Class_with_x8sub_0_in_tcGPR64_and_GPR64x8Class_with_x8sub_6_in_GPR64noipRegClassID = 472,
  GPR64x8Class_with_x8sub_0_in_tcGPRnotx16RegClassID = 473,
  GPR64x8Class_with_x8sub_1_in_tcGPR64RegClassID = 474,
  GPR64x8Class_with_x8sub_2_in_GPR64noip_and_GPR64x8Class_with_x8sub_0_in_GPR64noip_and_GPR64x8Class_with_x8sub_4_in_GPR64noipRegClassID = 475,
  GPR64x8Class_with_x8sub_2_in_GPR64noip_and_GPR64x8Class_with_x8sub_0_in_GPR64noip_and_GPR64x8Class_with_x8sub_6_in_GPR64noipRegClassID = 476,
  GPR64x8Class_with_x8sub_4_in_GPR64noip_and_GPR64x8Class_with_x8sub_0_in_GPR64noip_and_GPR64x8Class_with_x8sub_6_in_GPR64noipRegClassID = 477,
  GPR64x8Class_with_x8sub_4_in_GPR64noip_and_GPR64x8Class_with_x8sub_2_in_GPR64noip_and_GPR64x8Class_with_x8sub_6_in_GPR64noipRegClassID = 478,
  GPR64x8Class_with_x8sub_0_in_tcGPR64_and_GPR64x8Class_with_x8sub_0_in_GPR64noip_and_GPR64x8Class_with_x8sub_2_in_GPR64noipRegClassID = 479,
  GPR64x8Class_with_x8sub_0_in_tcGPR64_and_GPR64x8Class_with_x8sub_0_in_GPR64noip_and_GPR64x8Class_with_x8sub_4_in_GPR64noipRegClassID = 480,
  GPR64x8Class_with_x8sub_0_in_tcGPR64_and_GPR64x8Class_with_x8sub_0_in_GPR64noip_and_GPR64x8Class_with_x8sub_6_in_GPR64noipRegClassID = 481,
  GPR64x8Class_with_x8sub_1_in_tcGPR64_and_GPR64x8Class_with_x8sub_4_in_GPR64noipRegClassID = 482,
  GPR64x8Class_with_x8sub_1_in_tcGPR64_and_GPR64x8Class_with_x8sub_6_in_GPR64noipRegClassID = 483,
  GPR64x8Class_with_x8sub_1_in_tcGPRnotx16x17RegClassID = 484,
  GPR64x8Class_with_x8sub_2_in_GPR64noip_and_GPR64x8Class_with_x8sub_0_in_tcGPR64_and_GPR64x8Class_with_x8sub_4_in_GPR64noipRegClassID = 485,
  GPR64x8Class_with_x8sub_2_in_GPR64noip_and_GPR64x8Class_with_x8sub_0_in_tcGPR64_and_GPR64x8Class_with_x8sub_6_in_GPR64noipRegClassID = 486,
  GPR64x8Class_with_x8sub_2_in_tcGPRnotx16RegClassID = 487,
  GPR64x8Class_with_x8sub_4_in_GPR64noip_and_GPR64x8Class_with_x8sub_0_in_tcGPR64_and_GPR64x8Class_with_x8sub_6_in_GPR64noipRegClassID = 488,
  GPR64x8Class_with_x8sub_4_in_GPR64noip_and_GPR64x8Class_with_x8sub_2_in_GPR64noip_and_GPR64x8Class_with_x8sub_0_in_GPR64noip_and_GPR64x8Class_with_x8sub_6_in_GPR64noipRegClassID = 489,
  GPR64x8Class_with_x8sub_1_in_tcGPR64_and_GPR64x8Class_with_x8sub_0_in_GPR64noip_and_GPR64x8Class_with_x8sub_6_in_GPR64noipRegClassID = 490,
  GPR64x8Class_with_x8sub_2_in_GPR64noip_and_GPR64x8Class_with_x8sub_0_in_tcGPR64_and_GPR64x8Class_with_x8sub_0_in_GPR64noip_and_GPR64x8Class_with_x8sub_4_in_GPR64noipRegClassID = 491,
  GPR64x8Class_with_x8sub_2_in_GPR64noip_and_GPR64x8Class_with_x8sub_0_in_tcGPR64_and_GPR64x8Class_with_x8sub_0_in_GPR64noip_and_GPR64x8Class_with_x8sub_6_in_GPR64noipRegClassID = 492,
  GPR64x8Class_with_x8sub_2_in_GPR64noip_and_GPR64x8Class_with_x8sub_1_in_tcGPR64_and_GPR64x8Class_with_x8sub_4_in_GPR64noipRegClassID = 493,
  GPR64x8Class_with_x8sub_2_in_GPR64noip_and_GPR64x8Class_with_x8sub_1_in_tcGPR64_and_GPR64x8Class_with_x8sub_6_in_GPR64noipRegClassID = 494,
  GPR64x8Class_with_x8sub_3_in_tcGPRnotx16x17RegClassID = 495,
  GPR64x8Class_with_x8sub_4_in_GPR64noip_and_GPR64x8Class_with_x8sub_0_in_tcGPR64_and_GPR64x8Class_with_x8sub_0_in_GPR64noip_and_GPR64x8Class_with_x8sub_6_in_GPR64noipRegClassID = 496,
  GPR64x8Class_with_x8sub_4_in_GPR64noip_and_GPR64x8Class_with_x8sub_1_in_tcGPR64_and_GPR64x8Class_with_x8sub_6_in_GPR64noipRegClassID = 497,
  GPR64x8Class_with_x8sub_4_in_GPR64noip_and_GPR64x8Class_with_x8sub_2_in_GPR64noip_and_GPR64x8Class_with_x8sub_0_in_tcGPR64_and_GPR64x8Class_with_x8sub_6_in_GPR64noipRegClassID = 498,
  GPR64x8Class_with_x8sub_4_in_tcGPRnotx16RegClassID = 499,
  GPR64x8Class_with_x8sub_4_in_GPR64noip_and_GPR64x8Class_with_x8sub_1_in_tcGPR64_and_GPR64x8Class_with_x8sub_0_in_GPR64noip_and_GPR64x8Class_with_x8sub_6_in_GPR64noipRegClassID = 500,
  GPR64x8Class_with_x8sub_4_in_GPR64noip_and_GPR64x8Class_with_x8sub_2_in_GPR64noip_and_GPR64x8Class_with_x8sub_0_in_tcGPR64_and_GPR64x8Class_with_x8sub_0_in_GPR64noip_and_GPR64x8Class_with_x8sub_6_in_GPR64noipRegClassID = 501,
  GPR64x8Class_with_x8sub_4_in_GPR64noip_and_GPR64x8Class_with_x8sub_2_in_GPR64noip_and_GPR64x8Class_with_x8sub_1_in_tcGPR64_and_GPR64x8Class_with_x8sub_6_in_GPR64noipRegClassID = 502,
  GPR64x8Class_with_x8sub_5_in_tcGPRnotx16x17RegClassID = 503,
  GPR64x8Class_with_x8sub_6_in_tcGPRnotx16RegClassID = 504,
  GPR64x8Class_with_x8sub_7_in_tcGPRnotx16x17RegClassID = 505,
  GPR64x8Class_with_sub_32_in_GPR32argRegClassID = 506,
  MPR32RegClassID = 507,
  GPR64x8Class_with_x8sub_2_in_GPR64argRegClassID = 508,
  GPR64x8Class_with_sub_32_in_MatrixIndexGPR32_12_15RegClassID = 509,
  GPR64x8Class_with_sub_32_in_MatrixIndexGPR32_8_11RegClassID = 510,
  GPR64x8Class_with_x8sub_2_in_GPR64_with_sub_32_in_MatrixIndexGPR32_12_15RegClassID = 511,
  GPR64x8Class_with_x8sub_2_in_GPR64_with_sub_32_in_MatrixIndexGPR32_8_11RegClassID = 512,
  GPR64x8Class_with_x8sub_4_in_GPR64_with_sub_32_in_MatrixIndexGPR32_8_11RegClassID = 513,
  GPR64x8Class_with_x8sub_4_in_GPR64argRegClassID = 514,
  GPR64x8Class_with_x8sub_6_in_GPR64_with_sub_32_in_MatrixIndexGPR32_8_11RegClassID = 515,
  GPR64x8Class_with_sub_32_in_GPR32arg_and_GPR64x8Class_with_x8sub_2_in_GPR64_with_sub_32_in_MatrixIndexGPR32_8_11RegClassID = 516,
  GPR64x8Class_with_sub_32_in_MatrixIndexGPR32_8_11_and_GPR64x8Class_with_x8sub_2_in_GPR64_with_sub_32_in_MatrixIndexGPR32_8_11RegClassID = 517,
  GPR64x8Class_with_x8sub_0_in_tcGPRx16x17RegClassID = 518,
  GPR64x8Class_with_x8sub_2_in_GPR64arg_and_GPR64x8Class_with_x8sub_4_in_GPR64_with_sub_32_in_MatrixIndexGPR32_8_11RegClassID = 519,
  GPR64x8Class_with_x8sub_2_in_tcGPRx16x17RegClassID = 520,
  GPR64x8Class_with_x8sub_4_in_GPR64arg_and_GPR64x8Class_with_x8sub_6_in_GPR64_with_sub_32_in_MatrixIndexGPR32_8_11RegClassID = 521,
  GPR64x8Class_with_x8sub_4_in_tcGPRx16x17RegClassID = 522,
  GPR64x8Class_with_x8sub_6_in_GPR64argRegClassID = 523,
  GPR64x8Class_with_x8sub_6_in_tcGPRx16x17RegClassID = 524,
  GPR64x8Class_with_x8sub_7_in_FIXED_REGSRegClassID = 525,
  ZTRRegClassID = 526,
  MPR16RegClassID = 527,
  MPRRegClassID = 528,
  MPR8RegClassID = 529,

};
} // end namespace AArch64


// Register alternate name indices

namespace AArch64 {
enum {
  NoRegAltName,	// 0
  vlist1,	// 1
  vreg,	// 2
  NUM_TARGET_REG_ALT_NAMES = 3
};
} // end namespace AArch64


// Subregister indices

namespace AArch64 {
enum : uint16_t {
  NoSubRegister,
  bsub,	// 1
  bsub_hi,	// 2
  dsub,	// 3
  dsub0,	// 4
  dsub1,	// 5
  dsub2,	// 6
  dsub3,	// 7
  dsub_hi,	// 8
  hsub,	// 9
  hsub_hi,	// 10
  psub,	// 11
  psub0,	// 12
  psub1,	// 13
  qsub0,	// 14
  qsub1,	// 15
  qsub2,	// 16
  qsub3,	// 17
  ssub,	// 18
  ssub_hi,	// 19
  sub_32,	// 20
  sub_32_hi,	// 21
  sube32,	// 22
  sube64,	// 23
  subo32,	// 24
  subo64,	// 25
  x8sub_0,	// 26
  x8sub_1,	// 27
  x8sub_2,	// 28
  x8sub_3,	// 29
  x8sub_4,	// 30
  x8sub_5,	// 31
  x8sub_6,	// 32
  x8sub_7,	// 33
  zasubb,	// 34
  zasubd0,	// 35
  zasubd1,	// 36
  zasubh0,	// 37
  zasubh1,	// 38
  zasubq0,	// 39
  zasubq1,	// 40
  zasubs0,	// 41
  zasubs1,	// 42
  zsub,	// 43
  zsub0,	// 44
  zsub1,	// 45
  zsub2,	// 46
  zsub3,	// 47
  zsub_hi,	// 48
  zasubd1_then_zasubq0,	// 49
  zasubd1_then_zasubq1,	// 50
  zasubs1_then_zasubd0,	// 51
  zasubs1_then_zasubd1,	// 52
  zasubs1_then_zasubq0,	// 53
  zasubs1_then_zasubq1,	// 54
  zasubs1_then_zasubd1_then_zasubq0,	// 55
  zasubs1_then_zasubd1_then_zasubq1,	// 56
  zasubh1_then_zasubd0,	// 57
  zasubh1_then_zasubd1,	// 58
  zasubh1_then_zasubq0,	// 59
  zasubh1_then_zasubq1,	// 60
  zasubh1_then_zasubs0,	// 61
  zasubh1_then_zasubs1,	// 62
  zasubh1_then_zasubd1_then_zasubq0,	// 63
  zasubh1_then_zasubd1_then_zasubq1,	// 64
  zasubh1_then_zasubs1_then_zasubd0,	// 65
  zasubh1_then_zasubs1_then_zasubd1,	// 66
  zasubh1_then_zasubs1_then_zasubq0,	// 67
  zasubh1_then_zasubs1_then_zasubq1,	// 68
  zasubh1_then_zasubs1_then_zasubd1_then_zasubq0,	// 69
  zasubh1_then_zasubs1_then_zasubd1_then_zasubq1,	// 70
  dsub1_then_bsub,	// 71
  dsub1_then_bsub_hi,	// 72
  dsub1_then_hsub,	// 73
  dsub1_then_hsub_hi,	// 74
  dsub1_then_ssub,	// 75
  dsub1_then_ssub_hi,	// 76
  dsub3_then_bsub,	// 77
  dsub3_then_bsub_hi,	// 78
  dsub3_then_hsub,	// 79
  dsub3_then_hsub_hi,	// 80
  dsub3_then_ssub,	// 81
  dsub3_then_ssub_hi,	// 82
  dsub2_then_bsub,	// 83
  dsub2_then_bsub_hi,	// 84
  dsub2_then_hsub,	// 85
  dsub2_then_hsub_hi,	// 86
  dsub2_then_ssub,	// 87
  dsub2_then_ssub_hi,	// 88
  psub1_then_psub,	// 89
  qsub1_then_dsub_hi,	// 90
  qsub3_then_dsub_hi,	// 91
  qsub2_then_dsub_hi,	// 92
  x8sub_7_then_sub_32,	// 93
  x8sub_7_then_sub_32_hi,	// 94
  x8sub_6_then_sub_32,	// 95
  x8sub_6_then_sub_32_hi,	// 96
  x8sub_5_then_sub_32,	// 97
  x8sub_5_then_sub_32_hi,	// 98
  x8sub_4_then_sub_32,	// 99
  x8sub_4_then_sub_32_hi,	// 100
  x8sub_3_then_sub_32,	// 101
  x8sub_3_then_sub_32_hi,	// 102
  x8sub_2_then_sub_32,	// 103
  x8sub_2_then_sub_32_hi,	// 104
  x8sub_1_then_sub_32,	// 105
  x8sub_1_then_sub_32_hi,	// 106
  subo64_then_sub_32,	// 107
  subo64_then_sub_32_hi,	// 108
  zsub1_then_zsub_hi,	// 109
  zsub3_then_zsub_hi,	// 110
  zsub2_then_zsub_hi,	// 111
  dsub0_dsub1,	// 112
  dsub0_dsub1_dsub2,	// 113
  dsub1_dsub2,	// 114
  dsub1_dsub2_dsub3,	// 115
  dsub2_dsub3,	// 116
  dsub_dsub1,	// 117
  dsub_dsub1_dsub2_dsub3,	// 118
  dsub_dsub1_dsub2,	// 119
  qsub0_qsub1,	// 120
  qsub0_qsub1_qsub2,	// 121
  qsub1_qsub2,	// 122
  qsub1_qsub2_qsub3,	// 123
  qsub2_qsub3,	// 124
  sub_32_x8sub_1_then_sub_32,	// 125
  x8sub_0_x8sub_1,	// 126
  x8sub_2_x8sub_3,	// 127
  x8sub_4_x8sub_5,	// 128
  x8sub_6_x8sub_7,	// 129
  x8sub_6_then_sub_32_x8sub_7_then_sub_32,	// 130
  x8sub_4_then_sub_32_x8sub_5_then_sub_32,	// 131
  x8sub_2_then_sub_32_x8sub_3_then_sub_32,	// 132
  sub_32_subo64_then_sub_32,	// 133
  zsub_qsub1,	// 134
  zsub_qsub1_qsub2_qsub3,	// 135
  zsub_qsub1_qsub2,	// 136
  zsub0_zsub1,	// 137
  zsub0_zsub1_zsub2,	// 138
  zsub1_zsub2,	// 139
  zsub1_zsub2_zsub3,	// 140
  zsub2_zsub3,	// 141
  zsub0_zsub2,	// 142
  zsub1_zsub3,	// 143
  NUM_TARGET_SUBREGS
};
} // end namespace AArch64

// Register pressure sets enum.
namespace AArch64 {
enum RegisterPressureSets {
  ZTR = 0,
  PPR2_with_psub_in_PNR_3b_and_PPR2_with_psub1_in_PPR_p8to15 = 1,
  PPR2_with_psub_in_PNR_p8to15_and_PPR2_with_psub1_in_PPR_3b = 2,
  tcGPRx17 = 3,
  XSeqPairsClass_with_subo64_in_FIXED_REGS = 4,
  MatrixIndexGPR32_12_15 = 5,
  MatrixIndexGPR32_8_11 = 6,
  ZPRMul4_and_ZPR_K = 7,
  PPRMul2_and_PPR_3b = 8,
  PPRMul2_and_PPR_p8to15 = 9,
  FIXED_REGS = 10,
  ZPR4_with_zsub0_in_ZPR_K_and_ZPR4_with_zsub3_in_ZPRMul2_Hi = 11,
  ZPR4_with_zsub_in_FPR128_lo_and_ZPR4_with_zsub3_in_ZPRMul2_Hi = 12,
  ZPRMul2_Hi = 13,
  ZPRMul2_Lo = 14,
  ZPRMul4 = 15,
  ZPR2StridedOrContiguous_with_zsub0_in_ZPRMul2_Hi_and_ZPRMul4 = 16,
  ZPRMul2_Lo_and_ZPRMul4 = 17,
  ZPR2_with_zsub1_in_ZPRMul2_Hi_and_ZPRMul4 = 18,
  GPR64x8Class_with_x8sub_0_in_tcGPRx16x17 = 19,
  GPR64x8Class_with_x8sub_7_in_FIXED_REGS = 20,
  PPRMul2 = 21,
  PPRMul2_with_PPR2_with_psub_in_PNR_p8to15_and_PPR2_with_psub1_in_PPR_3b = 22,
  ZPRMul4_and_ZPR_K_with_ZPR4_with_zsub_in_FPR128_lo_and_ZPR4_with_zsub3_in_ZPRMul2_Hi = 23,
  PNR_3b = 24,
  PNR_p8to15 = 25,
  ZPR2_with_zsub1_in_ZPRMul2_Lo_and_ZPRMul4 = 26,
  ZPR4_with_zsub0_in_ZPR_K_and_ZPR4_with_zsub1_in_ZPRMul4 = 27,
  FIXED_REGS_with_GPR64x8Class_with_x8sub_7_in_FIXED_REGS = 28,
  ZPRMul4_and_ZPR_K_with_ZPR4_with_zsub0_in_ZPR_K_and_ZPR4_with_zsub1_in_ZPRMul4 = 29,
  ZPRMul2_Hi_with_ZPRMul4 = 30,
  ZPRMul2_Hi_with_ZPR4_with_zsub_in_FPR128_lo_and_ZPR4_with_zsub3_in_ZPRMul2_Hi = 31,
  ZPRMul2_Lo_with_ZPRMul4 = 32,
  ZPRMul4_with_ZPR2StridedOrContiguous_with_zsub0_in_ZPRMul2_Hi_and_ZPRMul4 = 33,
  ZPRMul4_with_ZPRMul2_Lo_and_ZPRMul4 = 34,
  ZPRMul4_with_ZPR2_with_zsub1_in_ZPRMul2_Hi_and_ZPRMul4 = 35,
  ZPRMul4_with_ZPR2_with_zsub1_in_ZPRMul2_Lo_and_ZPRMul4 = 36,
  ZPRMul4_with_ZPR2_with_zsub_in_FPR128_lo_and_ZPR2_with_zsub1_in_ZPRMul4 = 37,
  ZPR2StridedOrContiguous_with_zsub0_in_ZPRMul2_Hi_and_ZPRMul4_with_ZPR4_with_zsub_in_FPR128_lo_and_ZPR4_with_zsub3_in_ZPRMul2_Hi = 38,
  ZPR4_with_zsub3_in_ZPRMul4_and_ZPR_K_with_ZPR4_with_zsub_in_FPR128_lo_and_ZPR4_with_zsub3_in_ZPRMul2_Hi = 39,
  PPRMul2_with_PNR_3b = 40,
  PPRMul2_with_PNR_p8to15 = 41,
  ZPR3_with_zsub2_in_ZPRMul2_Hi_and_ZPRMul4 = 42,
  ZPRMul2_Lo_with_ZPR4_with_zsub_in_FPR128_lo_and_ZPR4_with_zsub3_in_ZPRMul2_Hi = 43,
  ZPRMul4_with_ZPR4_with_zsub0_in_ZPR_K_and_ZPR4_with_zsub3_in_ZPRMul2_Hi = 44,
  ZPRMul4_with_ZPR4_with_zsub_in_FPR128_lo_and_ZPR4_with_zsub3_in_ZPRMul2_Hi = 45,
  ZPRMul2_Lo_and_ZPRMul4_with_ZPR4_with_zsub_in_FPR128_lo_and_ZPR4_with_zsub3_in_ZPRMul2_Hi = 46,
  ZPRMul2_Lo_with_ZPR4_with_zsub0_in_ZPR_K_and_ZPR4_with_zsub1_in_ZPRMul4 = 47,
  ZPRMul4_with_ZPR4_with_zsub0_in_ZPR_K_and_ZPR4_with_zsub1_in_ZPRMul4 = 48,
  ZPRMul4_with_ZPR4_with_zsub3_in_ZPRMul4_and_ZPR_K = 49,
  ZPRMul2_Lo_and_ZPRMul4_with_ZPR4_with_zsub0_in_ZPR_K_and_ZPR4_with_zsub1_in_ZPRMul4 = 50,
  ZPR2_with_zsub1_in_ZPRMul2_Hi_and_ZPRMul4_with_ZPR4_with_zsub0_in_ZPR_K_and_ZPR4_with_zsub1_in_ZPRMul4 = 51,
  ZPR3_with_zsub_in_FPR128_lo_and_ZPR3_with_zsub1_in_ZPRMul4_with_ZPR4_with_zsub_in_FPR128_lo_and_ZPR4_with_zsub3_in_ZPRMul2_Hi = 52,
  FPR128_0to7_with_QQQQ_with_qsub3_in_FPR128_0to7 = 53,
  GPR64x8Class_with_x8sub_0_in_tcGPRx16x17_with_GPR64x8Class_with_x8sub_7_in_FIXED_REGS = 54,
  ZPRMul2_Hi_with_ZPR2_with_zsub_in_FPR128_lo_and_ZPR2_with_zsub1_in_ZPRMul4 = 55,
  ZPR2StridedOrContiguous_with_zsub0_in_ZPRMul2_Hi_and_ZPRMul4_with_ZPR2_with_zsub_in_FPR128_lo_and_ZPR2_with_zsub1_in_ZPRMul4 = 56,
  ZPR3_with_zsub0_zsub1_in_ZPR2Mul2_Hi_and_ZPR2_with_zsub0_in_ZPRMul4_with_ZPR4_with_zsub_in_FPR128_lo_and_ZPR4_with_zsub3_in_ZPRMul2_Hi = 57,
  ZPR3_with_zsub2_in_ZPRMul2_Lo_and_ZPRMul4_with_QQQQ_with_qsub3_in_FPR128_0to7 = 58,
  ZPR3_with_zsub_in_FPR128_lo_and_ZPR3_with_zsub2_in_ZPRMul4_with_ZPR4_with_zsub_in_FPR128_lo_and_ZPR4_with_zsub3_in_ZPRMul2_Hi = 59,
  QQQ_with_qsub2_in_FPR128_0to7_with_ZPR4_with_zsub0_in_ZPR_K_and_ZPR4_with_zsub1_in_ZPRMul4 = 60,
  QQQQ_with_qsub3_in_FPR128_0to7_with_ZPR4_with_zsub0_in_ZPR_K_and_ZPR4_with_zsub1_in_ZPRMul4 = 61,
  PPRorPNR = 62,
  ZPRMul2 = 63,
  ZPR2StridedOrContiguous_with_zsub0_in_ZPRMul4 = 64,
  ZPR2_with_zsub1_in_ZPRMul4 = 65,
  ZPRMul4_with_ZPR2StridedOrContiguous_with_zsub0_in_ZPRMul2_and_ZPR_3b = 66,
  ZPRMul4_with_ZPR3_with_zsub0_zsub1_in_ZPR2Mul2_Hi_and_ZPR2_with_zsub0_in_ZPRMul4 = 67,
  ZPRMul4_with_ZPR3_with_zsub0_zsub1_in_ZPR2Mul2_Lo_and_ZPR2_with_zsub0_in_ZPRMul4 = 68,
  ZPRMul4_with_ZPR3_with_zsub1_zsub2_in_ZPR2Mul2_Hi_and_ZPR2_with_zsub0_in_ZPRMul4 = 69,
  ZPRMul4_with_ZPR3_with_zsub1_zsub2_in_ZPR2Mul2_Lo_and_ZPR2_with_zsub0_in_ZPRMul4 = 70,
  ZPRMul4_with_ZPR3_with_zsub2_in_ZPRMul2_Hi_and_ZPRMul4 = 71,
  ZPRMul4_with_ZPR3_with_zsub2_in_ZPRMul2_Lo_and_ZPRMul4 = 72,
  ZPRMul4_with_ZPR3_with_zsub_in_FPR128_lo_and_ZPR3_with_zsub1_in_ZPRMul4 = 73,
  ZPRMul4_with_ZPR3_with_zsub_in_FPR128_lo_and_ZPR3_with_zsub2_in_ZPRMul4 = 74,
  ZPRMul4_with_FPR128_0to7 = 75,
  ZPRMul4_with_QQ_with_qsub1_in_FPR128_0to7 = 76,
  ZPRMul4_with_ZPR4StridedOrContiguous_with_zsub0_in_ZPRMul2_and_ZPR4StridedOrContiguous_with_zsub1_in_ZPR_K = 77,
  ZPR3_with_zsub0_zsub1_in_ZPR2Mul2_Lo_and_ZPR2_with_zsub0_in_ZPRMul4_with_ZPR4_with_zsub_in_FPR128_lo_and_ZPR4_with_zsub3_in_ZPRMul2_Hi = 78,
  ZPR3_with_zsub1_zsub2_in_ZPR2Mul2_Lo_and_ZPR2_with_zsub0_in_ZPRMul4_with_QQQQ_with_qsub3_in_FPR128_0to7 = 79,
  FPR128_0to7_with_ZPR4_with_zsub0_in_ZPR_K_and_ZPR4_with_zsub1_in_ZPRMul4 = 80,
  ZPR4StridedOrContiguous_with_zsub0_in_ZPRMul2_and_ZPR4StridedOrContiguous_with_zsub1_in_ZPR_K_with_ZPR4_with_zsub_in_FPR128_lo_and_ZPR4_with_zsub3_in_ZPRMul2_Hi = 81,
  GPR64x8Class_with_x8sub_6_in_tcGPRx16x17_with_GPR64x8Class_with_x8sub_0_in_tcGPRx16x17 = 82,
  ZPRMul4_with_QQQ_with_qsub2_in_FPR128_0to7 = 83,
  ZPRMul4_with_ZPR4_with_zsub0_zsub1_in_ZPR2Mul2_with_zsub0_zsub1_zsub2_in_ZPR3_with_zsub0_zsub1_in_ZPR2Mul2_Hi_and_ZPR3_with_zsub2_in_ZPRMul2_Hi_and_ZPRMul4 = 84,
  ZPRMul4_with_ZPR4_with_zsub1_in_ZPRMul2_with_zsub1_zsub2_zsub3_in_ZPR3_with_zsub0_zsub1_in_ZPR2Mul2_Hi_and_ZPR3_with_zsub2_in_ZPRMul2_Hi_and_ZPRMul4 = 85,
  ZPR2StridedOrContiguous_with_zsub0_in_ZPRMul2_and_ZPR_3b_with_ZPR4_with_zsub0_in_ZPR_K_and_ZPR4_with_zsub1_in_ZPRMul4 = 86,
  ZPR3_with_zsub0_zsub1_in_ZPR2Mul2_Lo_and_ZPR2_with_zsub0_in_ZPRMul4_with_ZPR4_with_zsub0_in_ZPR_K_and_ZPR4_with_zsub1_in_ZPRMul4 = 87,
  ZPR3_with_zsub1_zsub2_in_ZPR2Mul2_Lo_and_ZPR2_with_zsub0_in_ZPRMul4_with_ZPR4_with_zsub0_in_ZPR_K_and_ZPR4_with_zsub1_in_ZPRMul4 = 88,
  ZPR3_with_zsub_in_FPR128_lo_and_ZPR3_with_zsub1_in_ZPRMul4 = 89,
  ZPR3_with_zsub2_in_ZPRMul2_Hi_and_ZPRMul4_with_ZPR4_with_zsub0_in_ZPR_K_and_ZPR4_with_zsub1_in_ZPRMul4 = 90,
  ZPR3_with_zsub2_in_ZPRMul2_Lo_and_ZPRMul4_with_ZPR4_with_zsub0_in_ZPR_K_and_ZPR4_with_zsub1_in_ZPRMul4 = 91,
  ZPRMul2_Hi_with_QQQ_with_qsub2_in_FPR128_0to7 = 92,
  ZPRMul4_with_ZPR_K = 93,
  ZPR2StridedOrContiguous_with_zsub0_in_ZPRMul2_Hi_and_ZPRMul4_with_QQQQ_with_qsub3_in_FPR128_0to7 = 94,
  GPR64x8Class_with_x8sub_6_in_tcGPRx16x17 = 95,
  ZPRMul2_with_ZPR4_with_zsub0_in_ZPR_K_and_ZPR4_with_zsub3_in_ZPRMul2_Hi = 96,
  ZPRMul2_with_ZPR4_with_zsub_in_FPR128_lo_and_ZPR4_with_zsub3_in_ZPRMul2_Hi = 97,
  ZPRMul2_Hi_with_ZPR3_with_zsub_in_FPR128_lo_and_ZPR3_with_zsub1_in_ZPRMul4 = 98,
  ZPR2StridedOrContiguous_with_zsub0_in_ZPRMul4_with_ZPR4_with_zsub0_in_ZPR_K_and_ZPR4_with_zsub3_in_ZPRMul2_Hi = 99,
  ZPR2StridedOrContiguous_with_zsub0_in_ZPRMul4_with_ZPR4_with_zsub_in_FPR128_lo_and_ZPR4_with_zsub3_in_ZPRMul2_Hi = 100,
  ZPR2StridedOrContiguous_with_zsub0_in_ZPRMul2_Hi_and_ZPRMul4_with_ZPR3_with_zsub_in_FPR128_lo_and_ZPR3_with_zsub2_in_ZPRMul4 = 101,
  ZPR2_with_zsub1_in_ZPRMul2_Lo_and_ZPRMul4_with_ZPR4StridedOrContiguous_with_zsub0_in_ZPRMul2_and_ZPR4StridedOrContiguous_with_zsub1_in_ZPR_K = 102,
  ZPR2_with_zsub_in_FPR128_lo_and_ZPR2_with_zsub1_in_ZPRMul4_with_ZPR3_with_zsub0_zsub1_in_ZPR2Mul2_Hi_and_ZPR2_with_zsub0_in_ZPRMul4 = 103,
  ZPR2_with_zsub_in_FPR128_lo_and_ZPR2_with_zsub1_in_ZPRMul4_with_ZPR4StridedOrContiguous_with_zsub0_in_ZPRMul2_and_ZPR4StridedOrContiguous_with_zsub1_in_ZPR_K = 104,
  ZPR3_with_zsub_in_FPR128_lo_and_ZPR3_with_zsub1_in_ZPRMul4_with_ZPR4_with_zsub3_in_ZPRMul4_and_ZPR_K = 105,
  ZPR3_with_zsub_in_FPR128_lo_and_ZPR3_with_zsub2_in_ZPRMul4_with_ZPR4_with_zsub0_in_ZPR_K_and_ZPR4_with_zsub1_in_ZPRMul4 = 106,
  ZPRMul2_with_ZPR2StridedOrContiguous_with_zsub0_in_ZPRMul2_Hi_and_ZPRMul4 = 107,
  ZPRMul2_with_ZPRMul2_Lo_and_ZPRMul4 = 108,
  ZPRMul2_with_ZPR2_with_zsub1_in_ZPRMul2_Hi_and_ZPRMul4 = 109,
  ZPRMul2_with_ZPR2_with_zsub1_in_ZPRMul2_Lo_and_ZPRMul4 = 110,
  ZPRMul2_with_ZPR2_with_zsub_in_FPR128_lo_and_ZPR2_with_zsub1_in_ZPRMul4 = 111,
  ZPR2StridedOrContiguous_with_zsub0_in_ZPRMul4_with_ZPR2_with_zsub1_in_ZPRMul2_Hi_and_ZPRMul4 = 112,
  ZPR2StridedOrContiguous_with_zsub0_in_ZPRMul4_with_ZPR2_with_zsub1_in_ZPRMul2_Lo_and_ZPRMul4 = 113,
  ZPR2StridedOrContiguous_with_zsub0_in_ZPRMul4_with_ZPR2_with_zsub_in_FPR128_lo_and_ZPR2_with_zsub1_in_ZPRMul4 = 114,
  ZPR2_with_zsub1_in_ZPRMul4_with_ZPR2StridedOrContiguous_with_zsub0_in_ZPRMul2_Hi_and_ZPRMul4 = 115,
  ZPR2_with_zsub1_in_ZPRMul4_with_ZPRMul2_Lo_and_ZPRMul4 = 116,
  ZPR2_with_zsub1_in_ZPRMul4_with_ZPR3_with_zsub2_in_ZPRMul2_Hi_and_ZPRMul4 = 117,
  ZPR2_with_zsub1_in_ZPRMul4_with_ZPR3_with_zsub2_in_ZPRMul2_Lo_and_ZPRMul4 = 118,
  ZPR2_with_zsub1_in_ZPRMul4_with_ZPR3_with_zsub_in_FPR128_lo_and_ZPR3_with_zsub1_in_ZPRMul4 = 119,
  ZPR2_with_zsub1_in_ZPRMul4_with_ZPR4_with_zsub0_in_ZPR_K_and_ZPR4_with_zsub1_in_ZPRMul4 = 120,
  ZPR2_with_zsub1_in_ZPRMul4_with_ZPR4_with_zsub_in_FPR128_lo_and_ZPR4_with_zsub3_in_ZPRMul2_Hi = 121,
  ZPRMul4_with_ZPR4_with_zsub1_in_ZPR_K = 122,
  ZPR3_with_zsub1_zsub2_in_ZPR2Mul2_Hi_and_ZPR2_with_zsub0_in_ZPRMul4_with_ZPR3_with_zsub_in_FPR128_lo_and_ZPR3_with_zsub1_in_ZPRMul4 = 123,
  ZPR3_with_zsub2_in_ZPRMul2_Hi_and_ZPRMul4_with_ZPR3_with_zsub_in_FPR128_lo_and_ZPR3_with_zsub2_in_ZPRMul4 = 124,
  ZPRMul2_with_QQQQ_with_qsub3_in_FPR128_0to7 = 125,
  ZPRMul2_with_ZPR_K = 126,
  ZPRMul4_with_FPR16_lo = 127,
  ZPRMul4_with_DD_with_dsub1_in_FPR64_lo = 128,
  ZPRMul4_with_ZPR4_with_zsub2_in_ZPRMul2_Hi = 129,
  ZPRMul4_with_ZPR4_with_zsub3_in_ZPRMul2_Hi = 130,
  FPR16_lo = 131,
  ZPRMul2_Lo_and_ZPRMul4_with_ZPR_K = 132,
  ZPR2_with_zsub1_in_ZPRMul4_with_QQQ_with_qsub2_in_FPR128_0to7 = 133,
  ZPR3_with_zsub0_zsub1_in_ZPR2Mul2_Hi_and_ZPR2_with_zsub0_in_ZPRMul4_with_ZPR3_with_zsub_in_FPR128_lo_and_ZPR3_with_zsub1_in_ZPRMul4 = 134,
  ZPR3_with_zsub0_zsub1_in_ZPR2Mul2_Hi_and_ZPR2_with_zsub0_in_ZPRMul4_with_QQQ_with_qsub2_in_FPR128_0to7 = 135,
  ZPR3_with_zsub1_zsub2_in_ZPR2Mul2_Hi_and_ZPR2_with_zsub0_in_ZPRMul4_with_ZPR3_with_zsub_in_FPR128_lo_and_ZPR3_with_zsub2_in_ZPRMul4 = 136,
  ZPR3_with_zsub1_zsub2_in_ZPR2Mul2_Hi_and_ZPR2_with_zsub0_in_ZPRMul4_with_QQQQ_with_qsub3_in_FPR128_0to7 = 137,
  ZPR3_with_zsub2_in_ZPRMul2_Hi_and_ZPRMul4_with_ZPR3_with_zsub_in_FPR128_lo_and_ZPR3_with_zsub1_in_ZPRMul4 = 138,
  ZPR3_with_zsub2_in_ZPRMul2_Lo_and_ZPRMul4_with_ZPR_K = 139,
  ZPR3_with_zsub2_in_ZPRMul2_Lo_and_ZPRMul4_with_ZPR4StridedOrContiguous_with_zsub0_in_ZPRMul2_and_ZPR4StridedOrContiguous_with_zsub1_in_ZPR_K = 140,
  FPR128_0to7_with_ZPR_K = 141,
  ZPRMul2_Hi_with_QQQQ_with_qsub3_in_FPR128_0to7 = 142,
  ZPR_K = 143,
  ZPRMul4_with_DDD_with_dsub2_in_FPR64_lo = 144,
  DDD_with_dsub2_in_FPR64_lo_with_ZPR4_with_zsub0_in_ZPR_K_and_ZPR4_with_zsub1_in_ZPRMul4 = 145,
  DDDD_with_dsub3_in_FPR64_lo_with_ZPR4_with_zsub0_in_ZPR_K_and_ZPR4_with_zsub1_in_ZPRMul4 = 146,
  ZPR2StridedOrContiguous_with_zsub0_in_ZPRMul2_and_ZPR_3b_with_ZPR3_with_zsub2_in_ZPRMul2_Hi_and_ZPRMul4 = 147,
  ZPR2StridedOrContiguous_with_zsub0_in_ZPRMul2_and_ZPR_3b_with_ZPR_K = 148,
  ZPR3_with_zsub0_zsub1_in_ZPR2Mul2_Hi_and_ZPR2_with_zsub0_in_ZPRMul4_with_ZPR3_with_zsub2_in_ZPRMul2_Lo_and_ZPRMul4 = 149,
  ZPR3_with_zsub0_zsub1_in_ZPR2Mul2_Hi_and_ZPR2_with_zsub0_in_ZPRMul4_with_ZPR3_with_zsub_in_FPR128_lo_and_ZPR3_with_zsub2_in_ZPRMul4 = 150,
  ZPR3_with_zsub0_zsub1_in_ZPR2Mul2_Lo_and_ZPR2_with_zsub0_in_ZPRMul4_with_ZPR3_with_zsub2_in_ZPRMul2_Hi_and_ZPRMul4 = 151,
  ZPR3_with_zsub0_zsub1_in_ZPR2Mul2_Lo_and_ZPR2_with_zsub0_in_ZPRMul4_with_ZPR_K = 152,
  ZPR3_with_zsub1_zsub2_in_ZPR2Mul2_Lo_and_ZPR2_with_zsub0_in_ZPRMul4_with_ZPR_K = 153,
  ZPR3_with_zsub1_zsub2_in_ZPR2Mul2_Lo_and_ZPR2_with_zsub0_in_ZPRMul4_with_ZPR4StridedOrContiguous_with_zsub0_in_ZPRMul2_and_ZPR4StridedOrContiguous_with_zsub1_in_ZPR_K = 154,
  ZPR3_with_zsub_in_FPR128_lo_and_ZPR3_with_zsub1_in_ZPRMul4_with_ZPR4StridedOrContiguous_with_zsub0_in_ZPRMul2_and_ZPR4StridedOrContiguous_with_zsub1_in_ZPR_K = 155,
  ZPR3_with_zsub_in_FPR128_lo_and_ZPR3_with_zsub1_in_ZPRMul4_with_ZPR4_with_zsub1_in_ZPRMul2_with_zsub1_zsub2_zsub3_in_ZPR3_with_zsub0_zsub1_in_ZPR2Mul2_Hi_and_ZPR3_with_zsub2_in_ZPRMul2_Hi_and_ZPRMul4 = 156,
  ZPR3_with_zsub_in_FPR128_lo_and_ZPR3_with_zsub2_in_ZPRMul4_with_ZPR4StridedOrContiguous_with_zsub0_in_ZPRMul2_and_ZPR4StridedOrContiguous_with_zsub1_in_ZPR_K = 157,
  FPR16_lo_with_ZPR4_with_zsub0_in_ZPR_K_and_ZPR4_with_zsub1_in_ZPRMul4 = 158,
  ZPR2_with_zsub1_in_ZPRMul4_with_ZPR_K = 159,
  ZPRMul2_with_ZPR4_with_zsub1_in_ZPR_K = 160,
  ZPRMul2_with_ZPR4_with_zsub1_in_ZPRMul2_Hi = 161,
  ZPRMul2_with_ZPR4_with_zsub3_in_ZPRMul2_Hi = 162,
  FPR16_lo_with_ZPR2StridedOrContiguous_with_zsub0_in_ZPRMul4 = 163,
  ZPR2_with_zsub1_in_ZPRMul4_with_ZPR4_with_zsub1_in_ZPR_K = 164,
  ZPR3_with_zsub0_in_ZPRMul4_with_ZPR4_with_zsub_in_FPR128_lo_and_ZPR4_with_zsub3_in_ZPRMul2_Hi = 165,
  ZPR3_with_zsub_in_FPR128_lo_and_ZPR3_with_zsub2_in_ZPRMul4_with_ZPR_K = 166,
  GPR64x8Class_with_x8sub_0_in_tcGPR64 = 167,
  ZPRMul2_with_FPR16_lo = 168,
  FPR16_lo_with_ZPR4_with_zsub3_in_ZPRMul4_and_ZPR_K = 169,
  DD_with_dsub1_in_FPR64_lo_with_ZPR2StridedOrContiguous_with_zsub0_in_ZPRMul4 = 170,
  DDD_with_dsub2_in_FPR64_lo_with_ZPR2_with_zsub1_in_ZPRMul4 = 171,
  ZPR2StridedOrContiguous_with_zsub0_in_ZPRMul4_with_ZPR4_with_zsub1_in_ZPR_K = 172,
  ZPR2_with_zsub1_in_ZPRMul4_with_ZPR4_with_zsub3_in_ZPRMul2_Hi = 173,
  ZPR3_with_zsub1_in_ZPRMul4_with_ZPR_K = 174,
  FPR128_0to7_with_ZPR4_with_zsub1_in_ZPR_K = 175,
  QQ_with_qsub1_in_FPR128_0to7_with_ZPR4_with_zsub2_in_ZPRMul2_Hi = 176,
  QQQ_with_qsub2_in_FPR128_0to7_with_ZPR4_with_zsub3_in_ZPRMul2_Hi = 177,
  FPR16_lo_with_ZPR3_with_zsub1_in_ZPRMul4 = 178,
  FPR16_lo_with_ZPR3_with_zsub2_in_ZPRMul4 = 179,
  DDD_with_dsub2_in_FPR64_lo_with_ZPR3_with_zsub1_in_ZPRMul4 = 180,
  DDDD_with_dsub3_in_FPR64_lo_with_ZPR3_with_zsub2_in_ZPRMul4 = 181,
  QQQ_with_qsub2_in_FPR128_0to7_with_ZPR4_with_zsub2_in_ZPRMul2_Hi = 182,
  ZPR3_with_zsub0_in_ZPRMul4_with_ZPR_K = 183,
  ZPRMul2_Hi_with_ZPR3_with_zsub1_in_ZPRMul4 = 184,
  ZPR3_with_zsub2_in_ZPRMul4_with_ZPR_K = 185,
  ZPR3_with_zsub2_in_ZPRMul4_with_ZPR4_with_zsub3_in_ZPRMul2_Hi = 186,
  GPR64x8Class_with_x8sub_0_in_tcGPR64_with_GPR64x8Class_with_x8sub_7_in_FIXED_REGS = 187,
  FPR8 = 188,
  GPR32 = 189,
};
} // end namespace AArch64

} // end namespace llvm

